/*
 * Tirititran es un juego de naves en 2D ambientado en Cádiz
 * Copyright (C) 2004  Javier Pérez Pacheco
 *
 * Este juego tienen licencia Creative Commons y se permite
 * su modificacion y utilizacion libremente siempre y cuando se
 * cite al autor original y se comparta con la misma licencia.
 * No se permite su uso comercial.
 * 
 * Para mas informacion visite la web:
 * http://creativecommons.org/licenses/by-nc-sa/2.0/es/
 *
 * PROGRAMADOR
 * Javier Pérez Pacheco
 * Cadiz (Spain)
 * javi.pacheco@terra.es
 *
 * GRAFISMO Y 3D
 * Jesus Carrasco
 * Cadiz (Spain)
 * carrasco.carrasco@gmail.com
 *
 * MUSICA Y GRAFISMO
 * Shano Lores
 * Cadiz (Spain)
 * shano@mail.ono.es
 *
 */
 
 #include "disparosenemigos.h"
 
/*****************************
**
** CLASE DISPAROSENEMIGOS
**
******************************/
 
 DisparosEnemigos::DisparosEnemigos(Jugador *jug) {
	int i;
	char tmpch[127];
	 
	j = jug;

	// valores del seno y coseno en 16 posiciones separadas por 22.5 grados	 
	arSeno[0] = 0.000000;
	arCoseno[0] = 1.000000;
	arSeno[1] = 0.382683;
	arCoseno[1] = 0.923880;
	arSeno[2] = 0.707107;
	arCoseno[2] = 0.707107;
	arSeno[3] = 0.923880;
	arCoseno[3] = 0.382683;
	arSeno[4] = 1.000000;
	arCoseno[4] = -0.000000;
	arSeno[5] = 0.923880;
	arCoseno[5] = -0.382684;
	arSeno[6] = 0.707107;
	arCoseno[6] = -0.707107;
	arSeno[7] = 0.382683;
	arCoseno[7] = -0.923880;
	arSeno[8] = -0.000000;
	arCoseno[8] = -1.000000;
	arSeno[9] = -0.382683;
	arCoseno[9] = -0.923880;
	arSeno[10] = -0.707107;
	arCoseno[10] = -0.707107;
	arSeno[11] = -0.923880;
	arCoseno[11] = -0.382683;
	arSeno[12] = -1.000000;
	arCoseno[12] = 0.000000;
	arSeno[13] = -0.923880;
	arCoseno[13] = 0.382684;
	arSeno[14] = -0.707107;
	arCoseno[14] = 0.707107;
	arSeno[15] = -0.382683;
	arCoseno[15] = 0.923880;

	ciclos = 0;
	Frame frDisp_Peq0, frDisp_Peq1;
	Frame frDisp_Gr0, frDisp_Gr1, frDisp_Gr2, frDisp_Gr3;
	Frame frDisp_Rot0, frDisp_Rot1, frDisp_Rot2, frDisp_Rot3;
	Frame frPompaGr, frPompaPeq;
	 	
	// disparos pequeños
	sprintf (tmpch, "%s/balas.tim", DATA_DIR);
	frDisp_Peq0.loadFromRAR(tmpch, "balaenemigo1_0.timp");	
	frDisp_Peq1.loadFromRAR(tmpch, "balaenemigo1_1.timp");
	 
	for (i=0; i < MAXDISP_PEQ; i++) {
		disp_peq[i] = new Elemento(2);
		disp_peq[i]->addFrame(frDisp_Peq0);
		disp_peq[i]->addFrame(frDisp_Peq1);
		
		disp_peq[i]->selFrame(0);
		disp_peq[i]->setActivo(0);
	}
	
	// disparos grandes
	frDisp_Gr0.loadFromRAR(tmpch, "balaenemigo2_0.timp");
	frDisp_Gr1.loadFromRAR(tmpch, "balaenemigo2_1.timp");
	frDisp_Gr2.loadFromRAR(tmpch, "balaenemigo2_2.timp");
	frDisp_Gr3.loadFromRAR(tmpch, "balaenemigo2_3.timp");
	
	for (i=0; i < MAXDISP_GR; i++) {
		disp_gr[i] = new Elemento(4);
		disp_gr[i]->addFrame(frDisp_Gr0);
		disp_gr[i]->addFrame(frDisp_Gr1);
		disp_gr[i]->addFrame(frDisp_Gr2);
		disp_gr[i]->addFrame(frDisp_Gr3);
		
		disp_gr[i]->selFrame(0);
		disp_gr[i]->setActivo(0);
	}
	
	// disparos grandes
	frDisp_Gr0.loadFromRAR(tmpch, "balaenemigo3_0.timp");
	frDisp_Gr1.loadFromRAR(tmpch, "balaenemigo3_1.timp");
	frDisp_Gr2.loadFromRAR(tmpch, "balaenemigo3_2.timp");
	frDisp_Gr3.loadFromRAR(tmpch, "balaenemigo3_3.timp");
	
	for (i=0; i < MAXDISP_GR; i++) {
		disp_gr_azul[i] = new Elemento(4);
		disp_gr_azul[i]->addFrame(frDisp_Gr0);
		disp_gr_azul[i]->addFrame(frDisp_Gr1);
		disp_gr_azul[i]->addFrame(frDisp_Gr2);
		disp_gr_azul[i]->addFrame(frDisp_Gr3);
		
		disp_gr_azul[i]->selFrame(0);
		disp_gr_azul[i]->setActivo(0);
	}
	
	// disparos rotatorios
	frDisp_Rot0.loadFromRAR(tmpch, "bala_rotatoria0.timp");	
	frDisp_Rot1.loadFromRAR(tmpch, "bala_rotatoria1.timp");
	frDisp_Rot2.loadFromRAR(tmpch, "bala_rotatoria2.timp");
	frDisp_Rot3.loadFromRAR(tmpch, "bala_rotatoria3.timp");
	
	for (i=0; i < MAXDISP_ROT; i++) {
		disp_rot[i] = new Elemento(4);
		
		disp_rot[i]->addFrame(frDisp_Rot0);
		disp_rot[i]->addFrame(frDisp_Rot1);
		disp_rot[i]->addFrame(frDisp_Rot2);
		disp_rot[i]->addFrame(frDisp_Rot3);
		
		disp_rot[i]->selFrame(0);
		disp_rot[i]->setActivo(0);
	}
	
	// disparos pompas grandes
	frPompaGr.loadFromRAR(tmpch, "pompa_gr.timp");		
	
	for (i=0; i < MAXDISP_POMPA; i++) {
		pompa_gr[i] = new Elemento();
		
		pompa_gr[i]->addFrame(frPompaGr);

		pompa_gr[i]->selFrame(0);
		pompa_gr[i]->setActivo(0);
	}
	
	// disparos pompas grandes
	frPompaPeq.loadFromRAR(tmpch, "pompa_peq.timp");	
	for (i=0; i < MAXDISP_POMPA; i++) {
		pompa_peq[i] = new Elemento();
		pompa_peq[i]->addFrame(frPompaPeq);
		pompa_peq[i]->selFrame(0);
		pompa_peq[i]->setActivo(0);
	}
	
}

int DisparosEnemigos::elementoLibre (int ele) {
	int libre = -1;
	int i;
	switch (ele) {
		case DISPARO_PEQ:
			for (i=0; i < MAXDISP_PEQ; i++) {
				if (disp_peq[i]->getActivo() == 0) {
					libre = i;
				}
			}			
		break;
		case DISPARO_GR:
			for (i=0; i < MAXDISP_GR; i++) {
				if (disp_gr[i]->getActivo() == 0) {
					libre = i;
				}
			}			
		break;
		case DISPARO_GR_AZUL:
			for (i=0; i < MAXDISP_GR; i++) {
				if (disp_gr_azul[i]->getActivo() == 0) {
					libre = i;
				}
			}			
		break;
		case DISPARO_ROT:
			for (i=0; i < MAXDISP_ROT; i++) {
				if (disp_rot[i]->getActivo() == 0) {
					libre = i;
				}
			}			
		break;
		case DISPARO_POMPAGR:
			for (i=0; i < MAXDISP_POMPA; i++) {
				if (pompa_gr[i]->getActivo() == 0) {
					libre = i;
				}
			}			
		break;
		case DISPARO_POMPAPEQ:
			for (i=0; i < MAXDISP_POMPA; i++) {
				if (pompa_peq[i]->getActivo() == 0) {
					libre = i;
				}
			}			
		break;
	}
	return	libre;
}

void DisparosEnemigos::crearDisparoRetardado (int tipoDisparo, int movDisparo, float x, float y, float dirigirX, int posTorreta, int ciclosRetardo) {
	DisparoRetardado aux;
	aux.tipoDisparo = tipoDisparo;
	aux.movDisparo = movDisparo;
	aux.x = x;
	aux.y = y;
	aux.dirigirX = dirigirX;
	aux.posTorreta = posTorreta;
	aux.ciclo = ciclos + ciclosRetardo;
	disp_retardado.push_back(aux);
}

void DisparosEnemigos::lanzarDisparoRetardado () {
	
	vector<DisparoRetardado>::iterator e;
	
	e = disp_retardado.begin();

	for (int i=0; i<disp_retardado.size(); i++) {
		if (disp_retardado[i].ciclo == ciclos) {
			crearDisparo(disp_retardado[i].tipoDisparo, disp_retardado[i].movDisparo, disp_retardado[i].x, disp_retardado[i].y, disp_retardado[i].dirigirX, disp_retardado[i].posTorreta);
			disp_retardado.erase(e+i);
		}
	}
	
}

void DisparosEnemigos::crearDisparo(int tipoDisparo, int movDisparo,float x, float y, float dirigirX, int posTorreta) {
	int l; //, i, dx, dy; //, auxX, auxY
	int dirigidoX;
	int dirigidoY;
	float seno, coseno,dis, distanciaEntreElementos;
	switch (movDisparo) {
		case DISP_GRADO0:
		case DISP_GRADO1:
		case DISP_GRADO2:
		case DISP_GRADO3:
		case DISP_GRADO4:
		case DISP_GRADO5:
		case DISP_GRADO6:
		case DISP_GRADO7:
		case DISP_GRADO8:
		case DISP_GRADO9:
		case DISP_GRADO10:
		case DISP_GRADO11:
		case DISP_GRADO12:
		case DISP_GRADO13:
		case DISP_GRADO14:
		case DISP_GRADO15:
			if ( (tipoDisparo == DISPARO_POMPAGR) || (tipoDisparo == DISPARO_POMPAPEQ) ) {
				dis = 5.0;
			} else {
				dis = 8.0;
			}
			if (tipoDisparo == DISPARO_PEQ) {
				l = elementoLibre(DISPARO_PEQ);
				disp_peq[l]->setX(x - (disp_peq[l]->getAncho()/2) );
				disp_peq[l]->setY(y);
				disp_peq[l]->setTipoCoordenadas(COORDENADASPOLARES);
				disp_peq[l]->setDPolarSeno(-arSeno[movDisparo]);
				disp_peq[l]->setDPolarCoseno(arCoseno[movDisparo]);
				disp_peq[l]->setDPolarDistancia(dis);
				disp_peq[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_GR) {
				l = elementoLibre(DISPARO_GR);
				disp_gr[l]->setX(x - (disp_gr[l]->getAncho()/2) );
				disp_gr[l]->setY(y);
				disp_gr[l]->setTipoCoordenadas(COORDENADASPOLARES);
				disp_gr[l]->setDPolarSeno(-arSeno[movDisparo]);
				disp_gr[l]->setDPolarCoseno(arCoseno[movDisparo]);
				disp_gr[l]->setDPolarDistancia(dis);
				disp_gr[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_GR_AZUL) {
				l = elementoLibre(DISPARO_GR_AZUL);
				disp_gr_azul[l]->setX(x - (disp_gr_azul[l]->getAncho()/2) );
				disp_gr_azul[l]->setY(y);
				disp_gr_azul[l]->setTipoCoordenadas(COORDENADASPOLARES);
				disp_gr_azul[l]->setDPolarSeno(-arSeno[movDisparo]);
				disp_gr_azul[l]->setDPolarCoseno(arCoseno[movDisparo]);
				disp_gr_azul[l]->setDPolarDistancia(dis);
				disp_gr_azul[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_ROT) {
				l = elementoLibre(DISPARO_ROT);
				disp_rot[l]->setX(x - (disp_rot[l]->getAncho()/2) );
				disp_rot[l]->setY(y);
				disp_rot[l]->setTipoCoordenadas(COORDENADASPOLARES);
				disp_rot[l]->setDPolarSeno(-arSeno[movDisparo]);
				disp_rot[l]->setDPolarCoseno(arCoseno[movDisparo]);
				disp_rot[l]->setDPolarDistancia(dis);
				disp_rot[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_POMPAGR) {
				l = elementoLibre(DISPARO_POMPAGR);
				pompa_gr[l]->setX(x - (pompa_gr[l]->getAncho()/2) );
				pompa_gr[l]->setY(y);
				pompa_gr[l]->setTipoCoordenadas(COORDENADASPOLARES);
				pompa_gr[l]->setDPolarSeno(-arSeno[movDisparo]);
				pompa_gr[l]->setDPolarCoseno(arCoseno[movDisparo]);
				pompa_gr[l]->setDPolarDistancia(dis);
				pompa_gr[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_POMPAPEQ) {
				l = elementoLibre(DISPARO_POMPAPEQ);
				pompa_peq[l]->setX(x - (pompa_peq[l]->getAncho()/2) );
				pompa_peq[l]->setY(y);
				pompa_peq[l]->setTipoCoordenadas(COORDENADASPOLARES);
				pompa_peq[l]->setDPolarSeno(-arSeno[movDisparo]);
				pompa_peq[l]->setDPolarCoseno(arCoseno[movDisparo]);
				pompa_peq[l]->setDPolarDistancia(dis);
				pompa_peq[l]->setActivo(1);
			}
		break;
		case DISP_GRADOALJUGADOR:
			crearDisparo (tipoDisparo, posTorreta*2, x, y, 0, 0);
		break;
		case DISP_ALJUGADOR:
		case DISP_DIRIGIDO:
			if (movDisparo == DISP_ALJUGADOR) {
				dirigidoX = j->getCentroX();
				dirigidoY = j->getCentroY();
			} else {
				dirigidoX = dirigirX;
				dirigidoY = 550;
			}
			distanciaEntreElementos = sqrt( (dirigidoY-y)*(dirigidoY-y) + (dirigidoX-x)*(dirigidoX-x));
			seno = (float)(dirigidoY-y)/ distanciaEntreElementos;
			coseno = (float)(dirigidoX-x)/ distanciaEntreElementos;
			if ( (tipoDisparo == DISPARO_POMPAGR) || (tipoDisparo == DISPARO_POMPAPEQ) ) {
				dis = 5.0;
			} else {
				dis = 8.0;
			}
			if (tipoDisparo == DISPARO_PEQ) {
				l = elementoLibre(DISPARO_PEQ);
				disp_peq[l]->setX(x - (disp_peq[l]->getAncho()/2) );
				disp_peq[l]->setY(y);
				disp_peq[l]->setTipoCoordenadas(COORDENADASPOLARES);
				disp_peq[l]->setDPolarSeno(seno);
				disp_peq[l]->setDPolarCoseno(coseno);
				disp_peq[l]->setDPolarDistancia(dis);
				disp_peq[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_GR) {
				l = elementoLibre(DISPARO_GR);
				disp_gr[l]->setX(x - (disp_gr[l]->getAncho()/2) );
				disp_gr[l]->setY(y);
				disp_gr[l]->setTipoCoordenadas(COORDENADASPOLARES);
				disp_gr[l]->setDPolarSeno(seno);
				disp_gr[l]->setDPolarCoseno(coseno);
				disp_gr[l]->setDPolarDistancia(dis);
				disp_gr[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_GR_AZUL) {
				l = elementoLibre(DISPARO_GR_AZUL);
				disp_gr_azul[l]->setX(x - (disp_gr_azul[l]->getAncho()/2) );
				disp_gr_azul[l]->setY(y);
				disp_gr_azul[l]->setTipoCoordenadas(COORDENADASPOLARES);
				disp_gr_azul[l]->setDPolarSeno(seno);
				disp_gr_azul[l]->setDPolarCoseno(coseno);
				disp_gr_azul[l]->setDPolarDistancia(dis);
				disp_gr_azul[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_ROT) {
				l = elementoLibre(DISPARO_ROT);
				disp_rot[l]->setX(x - (disp_rot[l]->getAncho()/2) );
				disp_rot[l]->setY(y);
				disp_rot[l]->setTipoCoordenadas(COORDENADASPOLARES);
				disp_rot[l]->setDPolarSeno(seno);
				disp_rot[l]->setDPolarCoseno(coseno);
				disp_rot[l]->setDPolarDistancia(dis);
				disp_rot[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_POMPAGR) {
				l = elementoLibre(DISPARO_POMPAGR);
				pompa_gr[l]->setX(x - (pompa_gr[l]->getAncho()/2) );
				pompa_gr[l]->setY(y);
				pompa_gr[l]->setTipoCoordenadas(COORDENADASPOLARES);
				pompa_gr[l]->setDPolarSeno(seno);
				pompa_gr[l]->setDPolarCoseno(coseno);
				pompa_gr[l]->setDPolarDistancia(dis);
				pompa_gr[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_POMPAPEQ) {
				l = elementoLibre(DISPARO_POMPAPEQ);
				pompa_peq[l]->setX(x - (pompa_peq[l]->getAncho()/2) );
				pompa_peq[l]->setY(y);
				pompa_peq[l]->setTipoCoordenadas(COORDENADASPOLARES);
				pompa_peq[l]->setDPolarSeno(seno);
				pompa_peq[l]->setDPolarCoseno(coseno);
				pompa_peq[l]->setDPolarDistancia(dis);
				pompa_peq[l]->setActivo(1);
			}			
		break;
		case DISP_2ABAJO:
			if (tipoDisparo == DISPARO_PEQ) {
				l = elementoLibre(DISPARO_PEQ);
				disp_peq[l]->setX(x-28 - (disp_peq[l]->getAncho()/2));
				disp_peq[l]->setY(y);
				disp_peq[l]->setTipoCoordenadas(COORDENADASNORMALES);
				disp_peq[l]->setDX(0);
				disp_peq[l]->setDY(9);
				disp_peq[l]->setActivo(1);
				l = elementoLibre(DISPARO_PEQ);
				disp_peq[l]->setX(x+28 - (disp_peq[l]->getAncho()/2) );
				disp_peq[l]->setY(y);
				disp_peq[l]->setTipoCoordenadas(COORDENADASNORMALES);
				disp_peq[l]->setDX(0);
				disp_peq[l]->setDY(9);
				disp_peq[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_GR) {
				l = elementoLibre(DISPARO_GR);
				disp_gr[l]->setX(x-28 - (disp_gr[l]->getAncho()/2) );
				disp_gr[l]->setY(y);
				disp_gr[l]->setTipoCoordenadas(COORDENADASNORMALES);
				disp_gr[l]->setDX(0);
				disp_gr[l]->setDY(9);
				disp_gr[l]->setActivo(1);
				l = elementoLibre(DISPARO_GR);
				disp_gr[l]->setX(x+28 - (disp_gr[l]->getAncho()/2));
				disp_gr[l]->setY(y);
				disp_gr[l]->setTipoCoordenadas(COORDENADASNORMALES);
				disp_gr[l]->setDX(0);
				disp_gr[l]->setDY(9);
				disp_gr[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_GR_AZUL) {
				l = elementoLibre(DISPARO_GR_AZUL);
				disp_gr_azul[l]->setX(x-28 - (disp_gr_azul[l]->getAncho()/2) );
				disp_gr_azul[l]->setY(y);
				disp_gr_azul[l]->setTipoCoordenadas(COORDENADASNORMALES);
				disp_gr_azul[l]->setDX(0);
				disp_gr_azul[l]->setDY(9);
				disp_gr_azul[l]->setActivo(1);
				l = elementoLibre(DISPARO_GR_AZUL);
				disp_gr_azul[l]->setX(x+28 - (disp_gr_azul[l]->getAncho()/2));
				disp_gr_azul[l]->setY(y);
				disp_gr_azul[l]->setTipoCoordenadas(COORDENADASNORMALES);
				disp_gr_azul[l]->setDX(0);
				disp_gr_azul[l]->setDY(9);
				disp_gr_azul[l]->setActivo(1);
			} else if (tipoDisparo == DISPARO_ROT) {
				l = elementoLibre(DISPARO_ROT);
				disp_rot[l]->setX(x-28 - (disp_rot[l]->getAncho()/2) );
				disp_rot[l]->setY(y);
				disp_rot[l]->setTipoCoordenadas(COORDENADASNORMALES);
				disp_rot[l]->setDX(0);
				disp_rot[l]->setDY(9);
				disp_rot[l]->setActivo(1);
				l = elementoLibre(DISPARO_ROT);
				disp_rot[l]->setX(x+28 - (disp_rot[l]->getAncho()/2));
				disp_rot[l]->setY(y);
				disp_rot[l]->setTipoCoordenadas(COORDENADASNORMALES);
				disp_rot[l]->setDX(0);
				disp_rot[l]->setDY(9);
				disp_rot[l]->setActivo(1);
			}
		break;
		case DISP_8CIRCULAR:
			crearDisparo (tipoDisparo, DISP_GRADO12, x, y, 0, 0);
			crearDisparoRetardado (tipoDisparo, DISP_GRADO10, x, y, 0, 0, 5);
			crearDisparoRetardado (tipoDisparo, DISP_GRADO8, x, y, 0, 0, 10);
			crearDisparoRetardado (tipoDisparo, DISP_GRADO6, x, y, 0, 0, 15);
			crearDisparoRetardado (tipoDisparo, DISP_GRADO4, x, y, 0, 0, 20);
			crearDisparoRetardado (tipoDisparo, DISP_GRADO2, x, y, 0, 0, 25);
			crearDisparoRetardado (tipoDisparo, DISP_GRADO0, x, y, 0, 0, 30);
			crearDisparoRetardado (tipoDisparo, DISP_GRADO14, x, y, 0, 0, 35);
		break;
		case DISP_8:
			crearDisparo (tipoDisparo, DISP_GRADO12, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO10, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO8, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO6, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO4, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO2, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO0, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO14, x, y, 0, 0);
		break;
		case DISP_3ABAJO:
			crearDisparo (tipoDisparo, DISP_GRADO10, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO12, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO14, x, y, 0, 0);
		break;
		case DISP_3ABAJO_CERRADO:
			crearDisparo (tipoDisparo, DISP_GRADO11, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO12, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO13, x, y, 0, 0);
		break;
		case DISP_5ABAJO:
			crearDisparo (tipoDisparo, DISP_GRADO9, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO11, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO12, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO13, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO15, x, y, 0, 0);
		break;
		case DISP_6LATERALES:
			crearDisparo (tipoDisparo, DISP_GRADO3, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO0, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO13, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO5, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO8, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO11, x, y, 0, 0);
		break;
		case DISP_4OBLICUO:
			crearDisparo (tipoDisparo, DISP_GRADO2, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO6, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO10, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO14, x, y, 0, 0);
		break;
		case DISP_4CRUZ:
			crearDisparo (tipoDisparo, DISP_GRADO12, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO0, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO8, x, y, 0, 0);
			crearDisparo (tipoDisparo, DISP_GRADO4, x, y, 0, 0);
		break;
		case DISP_RAFAGA:
			crearDisparo (DISPARO_PEQ, DISP_DIRIGIDO, x-30, y, j->getX()+70, 0);
			crearDisparo (DISPARO_GR, DISP_DIRIGIDO, x-40, y+20, j->getX()+50, 0);
			crearDisparo (DISPARO_PEQ, DISP_DIRIGIDO, x+10, y, j->getX()-50, 0);
			crearDisparo (DISPARO_GR, DISP_DIRIGIDO, x+30, y-30, j->getX()-80, 0);
			crearDisparo (DISPARO_GR, DISP_DIRIGIDO, x-20, y-10, j->getX()-70, 0);
		break;
		case DISP_RAFAGA_MED:
			crearDisparo (NULL, DISP_RAFAGA, x, y, 0, 0);
			crearDisparoRetardado(NULL, DISP_RAFAGA, x, y, 0, 0, 10);
		break;
		case DISP_RAFAGA_GR:
			crearDisparo (NULL, DISP_RAFAGA, x, y, 0, 0);
			crearDisparoRetardado(NULL, DISP_RAFAGA, x, y, 0, 0, 10);
			crearDisparoRetardado(NULL, DISP_RAFAGA, x, y, 0, 0, 20);
			crearDisparoRetardado(NULL, DISP_RAFAGA, x, y, 0, 0, 30);
		break;
	}
	
}

void DisparosEnemigos::moverDisparo (SDL_Surface *sc) {
	int i;
	ciclos++;
	
	lanzarDisparoRetardado ();

	for (i=0; i < MAXDISP_PEQ; i++) {
		if (disp_peq[i]->getActivo() == 1) {
			disp_peq[i]->mover();
			if ( disp_peq[i]->fueraLimitesDePantalla() ){ 
				disp_peq[i]->setActivo(0);
			} else {
				if ( ciclos % 10 == 0 ) {
					disp_peq[i]->selSiguienteFrame();
				}
				disp_peq[i]->dibujar(sc);
			}
		}
	}
	
	for (i=0; i < MAXDISP_GR; i++) {
		if (disp_gr[i]->getActivo() == 1) {
			disp_gr[i]->mover();
			if ( disp_gr[i]->fueraLimitesDePantalla() ){ 
				disp_gr[i]->setActivo(0);
			} else {
				disp_gr[i]->selSiguienteFrame();
				disp_gr[i]->dibujar(sc);
			}
		}
	}
	
	for (i=0; i < MAXDISP_GR; i++) {
		if (disp_gr_azul[i]->getActivo() == 1) {
			disp_gr_azul[i]->mover();
			if ( disp_gr_azul[i]->fueraLimitesDePantalla() ){ 
				disp_gr_azul[i]->setActivo(0);
			} else {
				disp_gr_azul[i]->selSiguienteFrame();
				disp_gr_azul[i]->dibujar(sc);
			}
		}
	}	
	
	// rotatorios
	
	for (i=0; i < MAXDISP_ROT; i++) {
		if (disp_rot[i]->getActivo() == 1) {
			disp_rot[i]->mover();
			if ( disp_rot[i]->fueraLimitesDePantalla() ){ 
				disp_rot[i]->setActivo(0);
			} else {
				disp_rot[i]->selSiguienteFrame();
				disp_rot[i]->dibujar(sc);
			}
		}
	}	
	
	// pompas
	
	for (i=0; i < MAXDISP_POMPA; i++) {
		if (pompa_gr[i]->getActivo() == 1) {
			pompa_gr[i]->mover();
			if ( pompa_gr[i]->fueraLimitesDePantalla() ){ 
				pompa_gr[i]->setActivo(0);
			} else {
				pompa_gr[i]->selSiguienteFrame();
				pompa_gr[i]->dibujar(sc);
			}
		}
	}	
	
	for (i=0; i < MAXDISP_POMPA; i++) {
		if (pompa_peq[i]->getActivo() == 1) {
			pompa_peq[i]->mover();
			if ( pompa_peq[i]->fueraLimitesDePantalla() ){ 
				pompa_peq[i]->setActivo(0);
			} else {
				pompa_peq[i]->selSiguienteFrame();
				pompa_peq[i]->dibujar(sc);
			}
		}
	}	
	
}

 void DisparosEnemigos::iniciar () {
	 int i;
	 ciclos = 0;
	 for (i=0; i < MAXDISP_PEQ; i++) {
		 disp_peq[i]->setActivo(0);
	 }
	 
	 for (i=0; i < MAXDISP_GR; i++) {
		 disp_gr[i]->setActivo(0);
		 disp_gr_azul[i]->setActivo(0);
	 }
	 
	 for (i=0; i < MAXDISP_ROT; i++) {
		 disp_rot[i]->setActivo(0);
	 }

	 for (i=0; i < MAXDISP_POMPA; i++) {
		 pompa_gr[i]->setActivo(0);
		 pompa_peq[i]->setActivo(0);
	 }
	 vaciarDisparoRetardado();
}

bool DisparosEnemigos::colisionConJugador() {
	int i;
	for (i=0; i < MAXDISP_PEQ; i++) {
		if ( disp_peq[i]->colision(j) && disp_peq[i]->getActivo() == 1 && j->getFantasma() == 0  ) {
			disp_peq[i]->setActivo(0);
			return 1;
		}
	}
	
	for (i=0; i < MAXDISP_GR; i++) {
		if (disp_gr[i]->colision(j)  && disp_gr[i]->getActivo() == 1  && j->getFantasma() == 0) {
			disp_gr[i]->setActivo(0);
			return 1;
		}
		if (disp_gr_azul[i]->colision(j)  && disp_gr_azul[i]->getActivo() == 1  && j->getFantasma() == 0) {
			disp_gr_azul[i]->setActivo(0);
			return 1;
		}
	}
	
	
	for (i=0; i < MAXDISP_ROT; i++) {
		if (disp_rot[i]->colision(j)  && disp_rot[i]->getActivo() == 1  && j->getFantasma() == 0) {
			disp_rot[i]->setActivo(0);
			return 1;
		}
	}
	
	for (i=0; i < MAXDISP_POMPA; i++) {
		if (pompa_gr[i]->colision(j)  && pompa_gr[i]->getActivo() == 1  && j->getFantasma() == 0) {
			pompa_gr[i]->setActivo(0);
			return 1;
		}
		if (pompa_peq[i]->colision(j)  && pompa_peq[i]->getActivo() == 1  && j->getFantasma() == 0) {
			pompa_peq[i]->setActivo(0);
			return 1;
		}
	}
	
	return 0;
}

void DisparosEnemigos::colisionConDisparosJugador(Elemento *b, Explosion *exp, Audio *son) {
	int i;
		
	for (i=0; i < MAXDISP_GR; i++) {
		if (disp_gr[i]->colision(b)  && disp_gr[i]->getActivo() == 1 && b->getActivo() == 1 ) {
			disp_gr[i]->setActivo(0);
			b->setActivo(0);
			exp->crearExplosion( EXP_DISPARO_GR, disp_gr[i]->getCentroX(), disp_gr[i]->getCentroY() );
		}
		if (disp_gr_azul[i]->colision(b)  && disp_gr_azul[i]->getActivo() == 1 && b->getActivo() == 1 ) {
			disp_gr_azul[i]->setActivo(0);
			b->setActivo(0);
			exp->crearExplosion( EXP_DISPARO_GR_AZUL, disp_gr_azul[i]->getCentroX(), disp_gr_azul[i]->getCentroY() );
		}
	}
	
	for (i=0; i < MAXDISP_POMPA; i++) {
		if (pompa_gr[i]->colision(b)  && pompa_gr[i]->getActivo() == 1 && b->getActivo() == 1 ) {
			pompa_gr[i]->setActivo(0);
			b->setActivo(0);
			crearDisparo (DISPARO_POMPAPEQ, DISP_DIRIGIDO, pompa_gr[i]->getCentroX(), pompa_gr[i]->getCentroY(), 450, 0);
			crearDisparo (DISPARO_POMPAPEQ, DISP_DIRIGIDO, pompa_gr[i]->getCentroX(), pompa_gr[i]->getCentroY(), 50, 0);
			exp->crearExplosion( EXP_POMPAGR, pompa_gr[i]->getCentroX(), pompa_gr[i]->getCentroY() );
			son->playSonido(SND_POP);
		}
		if (pompa_peq[i]->colision(b)  && pompa_peq[i]->getActivo() == 1 && b->getActivo() == 1 ) {
			pompa_peq[i]->setActivo(0);
			b->setActivo(0);
			exp->crearExplosion( EXP_POMPAPEQ, pompa_peq[i]->getCentroX(), pompa_peq[i]->getCentroY() );
			son->playSonido(SND_POP);
		}
	}
	
}

void DisparosEnemigos::unLoad() {
	int i;

	for (i=0; i < MAXDISP_PEQ; i++) {
		disp_peq[i]->unLoad();
	}
	
	for (i=0; i < MAXDISP_GR; i++) {
		disp_gr[i]->unLoad();
		disp_gr_azul[i]->unLoad();
	}
	
	for (i=0; i < MAXDISP_ROT; i++) {
		disp_rot[i]->unLoad();
	}
	
	for (i=0; i < MAXDISP_POMPA; i++) {
		pompa_gr[i]->unLoad();
		pompa_peq[i]->unLoad();
	}
	
	vaciarDisparoRetardado();
	
}
