/*
 * Tirititran es un juego de naves en 2D ambientado en Cádiz
 * Copyright (C) 2004  Javier Pérez Pacheco
 *
 * Este juego tienen licencia Creative Commons y se permite
 * su modificacion y utilizacion libremente siempre y cuando se
 * cite al autor original y se comparta con la misma licencia.
 * No se permite su uso comercial.
 * 
 * Para mas informacion visite la web:
 * http://creativecommons.org/licenses/by-nc-sa/2.0/es/
 *
 * PROGRAMADOR
 * Javier Pérez Pacheco
 * Cadiz (Spain)
 * javi.pacheco@terra.es
 *
 * GRAFISMO Y 3D
 * Jesus Carrasco
 * Cadiz (Spain)
 * carrasco.carrasco@gmail.com
 *
 * MUSICA Y GRAFISMO
 * Shano Lores
 * Cadiz (Spain)
 * shano@mail.ono.es
 *
 */
 
 #include "pantalla.h"

 Pantalla::Pantalla() {
	srand(time(NULL));
	screen_w = 520;
	screen_h = 480;
	pantalla_w = 640;
	pantalla_h = 480;
	nScreenShot = 0;
	 
	clip_recortado.x = 0;
	clip_recortado.y = 0;
	clip_recortado.h = screen_h;
	clip_recortado.w = screen_w;

	// archivo de configuracion del juego
	config = new Configuracion();
	config->configurar();

	// Iniciamos SDL
	 
	if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_JOYSTICK | SDL_INIT_AUDIO) < 0)
	{
		printf ("No se puede iniciar SDL: %s\n", SDL_GetError());
		salir = 1;
	}

	SDL_ShowCursor(0);
	SDL_WM_SetCaption("Tirititran: El super-heroe gaditano", "Tirititran: El super-heroe gaditano");

	
	// abrimos intercom
	intercom = new Intercom(getConfiguracion());
	
	modoScreen ();
	
	// cargamos fuente	
	fuente = new Fuente();
	fuente->initFuente();
	
	// iniciamos opciones
	opciones = new Opciones(this);
	
	// velocidad del juego
	
	if (config->getOpcion("vel_juego") == 0) {
		velocidadJuego = 55;
	} else if (config->getOpcion("vel_juego") == 2) {
		velocidadJuego = 35;
	} else {
		velocidadJuego = 45;
	}
	
	// cargar animacion de la portada
	
	char cadena[127], archivo[27];
	introPortada = new SDL_Animation(screen, 640, 480);
	sprintf (cadena, "%s/verabd.tttf", DATA_DIR);
	introPortada->inVariable("fuente", cadena);
	introPortada->inVariable("conf_ruta", getConfiguracion()->getDirectorio());
	sprintf (cadena, "%s/portada.tin", DATA_DIR);
	sprintf (archivo, "portada.tin");
	introPortada->loadBuffer(BufferFromRar(cadena, "portada.txml"), archivo);

}



Uint32 Pantalla::timeLeft(void)
{
    Uint32 now;

    now = SDL_GetTicks();
    if(next_time <= now)
        return 0;
    else
        return next_time - now;
}

void Pantalla::nextTime()
{
	next_time = SDL_GetTicks() + velocidadJuego;
}

void Pantalla::guardarImg () {
	char tmpch[127];
	sprintf(tmpch, "%s/img.bmp", getConfiguracion()->getDirectorio());
	negro->dibujar(screen);
	SDL_Flip(screen);
	
	SDL_SaveBMP(screen, tmpch);
}

void Pantalla::guardarImgTemblor () {
	char tmpch[127];
	sprintf(tmpch, "%s/img.bmp", getConfiguracion()->getDirectorio());
	SDL_Flip(screen);

	SDL_SaveBMP(screen, tmpch);
}

int Pantalla::xEnPantalla (int x) {
	if (screen_w != 520) {
		return screen_w * x / 520;
	}
	return x;
}

int Pantalla::yEnPantalla (int y) {
	if (screen_h != 480) {
		return screen_h * y / 480;
	}
	return y;
}

int Pantalla::xEnPantalla (int div, int mul) {
	return (screen_w/div)*mul;
}

int Pantalla::yEnPantalla (int div, int mul) {
	return (screen_h/div)*mul;
}

void Pantalla::cargarConfiguracion () {
	sonido->establecerVolumenes();
	modoScreen ();
}

void Pantalla::modoScreen () {
	printf("Configuramos pantalla\n");
	
	Uint32 flags;
	int screen_bpp;
	
	if ( config->getOpcion("ace_hardware") == 1 ) {
		flags = SDL_HWSURFACE | SDL_DOUBLEBUF;
	} else {
		flags = SDL_SWSURFACE | SDL_DOUBLEBUF;
	}
	
	if ( config->getOpcion("bpp") == 1 ) {
		screen_bpp = 24;
	} else if ( config->getOpcion("bpp") == 2 ) {
		screen_bpp = 32;
	} else {
		screen_bpp = 16;
	}		

	if ( config->getOpcion("fullscreen") == 1 ) {
		flags |= SDL_FULLSCREEN;
		if (getenv("HOME") == NULL) // si es windows forzamos 24bpp
			screen_bpp = 24;
	}
	
		
	screen = SDL_SetVideoMode (screen_w+120, screen_h, screen_bpp, flags);
	
	if (screen == NULL)
	{
		printf ("No se puede iniciar el modo gráfico: %s\n", SDL_GetError());
		salir = 1;
	}
	
	intercom->setScreen(screen);
	
	printf("Terminada configuracion de pantalla\n");
}

void Pantalla::entradaJugador () {
	juego->setTiempoPoder(0);
	juego->setTipoDisparo(0);
	juego->setPoderActivo(0);
	//juego->removeVidas();
	juego->setHacerClip(0);
	jugador->setFantasma(1);
	jugador->setEstado(1);
	cicloEstadoNaciendoFin = juego->getCiclos() + TIEMPOENTRADAJUGADOR;
}

void Pantalla::morirJugador () {
	if ( (juego->getPoderes()>0) || (juego->getBarraPoder() >0) ) {
		crearAgregador(AG_PODER, jugador->getX(), jugador->getY()-50, 4, -4);
	}
	if (juego->getTipoDisparo()>0) {
		crearAgregador(AG_DISPARO, jugador->getX(), jugador->getY()-50, -4, -4);
	}
	jugador->morir(sonido); // estado de muerte de jugador
}

void Pantalla::usarPoder () {
	switch (juego->getPoderSel()) {
		case 1:
			sonido->playSonido(SND_FRASE_ESCUDO);
			juego->setPoderActivo(1);
		break;
		case 2:
			estela_bomba->setActivo(1);
			cicloEstela = 0;
			eliminarEnemigosPantalla();
			sonido->playSonido(SND_BOMBA);
		break;
		case 3:
			if (rand()%2==0) {
				sonido->playSonido(SND_FRASE_CLONACION0);
			} else {
				sonido->playSonido(SND_FRASE_CLONACION1);
			}
			juego->setPoderActivo(1);
		break;
		case 4:
			sonido->playSonido(SND_ESE_CADI);
			cicloEstela = 0;
			disp_ene->iniciar();
			for (int i=0; i<MAX_BALON; i++) {
				jugador->getDisparoJugador()->balon[i]->iniciar();
				jugador->getDisparoJugador()->balon[i]->setActivo(1);
			}
			EnPoderCadista = true;
		break;
	}
}

void Pantalla::dibujarJugador () {
	// dibujar jugador
	if (jugador->getEstado() == 1) { // entrando
		if ( juego->getCiclos() < cicloEstadoNaciendoFin - 60 ) {
			if (jugador->comprobarTeclas(juego, joystick, sonido, false, false, true)) usarPoder();
			jugador->addY(-4);
		} else {
			if (jugador->comprobarTeclas(juego, joystick, sonido, true, true, true)) usarPoder();
		}
		if ( cicloEstadoNaciendoFin < juego->getCiclos() ) {
			jugador->setEstado(2);
			jugador->setFantasma(0);
		}
	} else if (jugador->getEstado() == 0) { // muriendo
		jugador->setFantasma(1);
	} else if (jugador->getEstado() == 3) { // muerto
		juego->setPoderes(2);
		juego->removeVidas();
		entradaJugador();
	} else if (jugador->getEstado() == 4) { // saliendo de fase
		jugador->addY(-18);
		jugador->setFantasma(1);
	} else { // vivito y coleando
		if (jugador->comprobarTeclas(juego, joystick, sonido, true, true, true)) usarPoder();
	}

	jugador->dibujar(screen, juego, joystick, sonido);
	
}


void Pantalla::comprobarEstelaBomba () {
	// mover estela de la bomba
	
	if (estela_bomba->getActivo() == 1) {
		// bloqueamos los disparos por un tiempo
		if (getFinal()>0) {
			switch(juego->getNivel()) {
				case 1:
					jefe1->bloquearDisparos();
				break;
				case 2:
					jefe2->bloquearDisparos();
				break;
				case 3:
					jefe3[0]->bloquearDisparos();
					jefe3[1]->bloquearDisparos();
					jefe3[2]->bloquearDisparos();
					biopic->bloquearDisparos();
				break;
			}
		} 
		tiempoBloqueoDisparosEnemigos = TIEMPOBLOQUEODISPAROSENEMIGOS;
		// movemos estela
		estela_bomba->mover();
		estela_bomba->dibujar(screen);
		// parpadeo en rojo
		if ( cicloEstela%2 == 0 ) {
			rojo->dibujar(screen);
		}
		char tmpdir[120];
		SDL_Rect r;
		if ( cicloEstela%14 <= 8 ) {
			if (cicloEstela%7 == 1) {
				r.x = -15;
				r.y = -13;
			} else if (cicloEstela%7 == 3) {
				r.x = -8;
				r.y = 5;
			} else if (cicloEstela%7 == 2) {
				r.x = 15;
				r.y = 18;
			} else 	if (cicloEstela%7 == 5) {
				r.x = -5;
				r.y = -3;
			} else if (cicloEstela%7 == 7) {
				r.x = -3;
				r.y = 2;
			} else {
				r.x = 5;
				r.y = 4;
			}
			guardarImgTemblor();
			sprintf(tmpdir, "%s/img.bmp", config->getDirectorio());
			SDL_BlitSurface (SDL_LoadBMP(tmpdir), NULL, screen, &r);
		}
		cicloEstela ++;
		if (estela_bomba->fueraLimitesDePantalla()) {
			mapa->play();
			estela_bomba->setActivo(0);
			estela_bomba->setY(screen_h);
			cicloEstela = 0;
		}
	}

}

void Pantalla::comprobarBalones() {
	int i;
	DisparoJugador* disp_jugador = jugador->getDisparoJugador();	
	
	if (EnPoderCadista) {
		// bloqueamos los disparos por un tiempo
		if (getFinal()>0) {
			switch(juego->getNivel()) {
				case 1:
					jefe1->bloquearDisparos();
				break;
				case 2:
					jefe2->bloquearDisparos();
				break;
				case 3:
					jefe3[0]->bloquearDisparos();
					jefe3[1]->bloquearDisparos();
					jefe3[2]->bloquearDisparos();
					biopic->bloquearDisparos();
				break;
			}
		} 
		cicloEstela ++;
		// parpadeo en blanco
		if ( cicloEstela % 7 < 3 ) {
			amarillo->dibujar(screen);
		}
		tiempoBloqueoDisparosEnemigos = TIEMPOBLOQUEODISPAROSENEMIGOS;
		for (i=0; i<MAX_BALON; i++) {
			if (disp_jugador->balon[i]->getActivo()) {
				if ( (disp_jugador->balon[i]->getX() < 0) || (disp_jugador->balon[i]->getX() > ( screen_w-disp_jugador->balon[i]->getAncho() ) ) )
					disp_jugador->balon[i]->cambiarVelHorizontal();
				disp_jugador->balon[i]->mover();
				disp_jugador->balon[i]->dibujar(screen);
				// sólo desactivar cuando sale por arriba
				if (disp_jugador->balon[i]->getY() < disp_jugador->balon[i]->getLimiteSup()) {
					disp_jugador->balon[i]->setActivo(0);
				}
			}
		}
	}
	
	EnPoderCadista = false;
	
	for (i=0; i<MAX_BALON; i++) {
		if (disp_jugador->balon[i]->getActivo()==1) {
			EnPoderCadista = true;
			break;
		}
	}
	if (!EnPoderCadista)
		cicloEstela = 0;
}


void Pantalla::Escena () {
	juego->addCiclos();

	if (juego->getHacerClip()==1) {
		SDL_SetClipRect (screen, &clip_recortado);
	} else {
		//printf("%d\n", juego->getHacerClip());
		SDL_SetClipRect (screen, NULL);
		juego->setHacerClip(1);
	}
	
	if (final>0) {
		EscenaFinal();
		comprobarScreenShot();
		return;
	}
	
	//jugador->setFantasma(1);
	// mostrar mapa
	
	mapa->dibujarMapa(screen);
	dibujarNubes();

	explosiones->dibujarExplosionTierra(screen);
	moverEnemigoTierra();
	mapa->dibujarElementos (screen, juego);
	dibujarElTiempo();
	moverEnemigoAire();
	explosiones->dibujarExplosionAire(screen);
	dibujarAgregadores();
	
	crearDisparoEnemigo();
	disp_ene->moverDisparo(screen);
	jugador->getDisparoJugador()->mover(screen);

	comprobarColisiones();
		
	crearElemento();
	
	dibujarJugador ();
	
	dibujarChispas();
	
	// letreto de nivel
	
	if ( ciclosNivel > 0 ) {
		banda_Nivel->dibujar(screen);
		//if (txtNivel->getX() < screen_w/2) { txtNivel->addX(20); }
		//if (txtFase->getX() > screen_w/2) { txtFase->addX(-20); }
		txtNivel->mover();
		txtNivel->dibujar(screen);
		txtFase->mover();
		txtFase->dibujar(screen);
		
		if ( ciclosNivel == 10 ) {
			txtFase->setPorPosicionX(-txtFase->getAncho()-50);
			txtNivel->setPorPosicionX(screen_w+50);
		}
		
		ciclosNivel--;
	}
	
	comprobarEstelaBomba();
	comprobarBalones();

	barra->dibujarBarra(screen, juego, intercom);
	
	// contador de ciclos
	
	/*int clicos_mostrar = juego->getCiclos() - juego->getCiclos() % 10;
	char tmpuntos[10];
	sprintf (tmpuntos, "%d", clicos_mostrar);
	fuente->escribirTexto(screen, 0, ALIGN_LEFT, VALIGN_TOP, 12, tmpuntos, 255, 255, 255, 0, 0, 0, 10, 10);
	*/
	comprobarScreenShot();

	SDL_Flip (screen);
}

void Pantalla::EscenaEnComoJugar () {

	if (frameCartelMostrar == -1) {
		juego->addCiclos();

		if (juego->getCiclos()>890) {
			mapa->dibujarMapa(screen);
			if (mitadLogoAbajo->getY()>240)
				mitadLogoAbajo->mover();
			if (mitadLogoArriba->getY()<0)
				mitadLogoArriba->mover();
			mitadLogoAbajo->dibujar(screen);
			mitadLogoArriba->dibujar(screen);
			
			barra->dibujarBarra(screen, juego, intercom);
			
			crearElemento();
			
			SDL_Flip (screen);
			return;
		}
		
		if (juego->getHacerClip()==1) {
			SDL_SetClipRect (screen, &clip_recortado);
		} else {
			//printf("%d\n", juego->getHacerClip());
			SDL_SetClipRect (screen, NULL);
			juego->setHacerClip(1);
		}
		
		// mostrar mapa
		
		mapa->dibujarMapa(screen);
	
		explosiones->dibujarExplosionTierra(screen);
		moverEnemigoTierra();
		mapa->dibujarElementos (screen, juego);
		dibujarElTiempo();
		moverEnemigoAire();
		explosiones->dibujarExplosionAire(screen);
		dibujarAgregadores();
		
		crearDisparoEnemigo();
		disp_ene->moverDisparo(screen);
		jugador->getDisparoJugador()->mover(screen);
	
		comprobarColisiones();
		
		dibujarJugador ();
		
		dibujarChispas();
		
		// letreto de nivel
		
		if ( ciclosNivel > 0 ) {
			banda_Nivel->dibujar(screen);
			txtNivel->mover();
			txtNivel->dibujar(screen);
			txtFase->mover();
			txtFase->dibujar(screen);
			
			if ( ciclosNivel == 10 ) {
				txtFase->setPorPosicionX(-txtFase->getAncho()-50);
				txtNivel->setPorPosicionX(screen_w+50);
			}
			
			ciclosNivel--;
		}
		
		comprobarEstelaBomba();
		comprobarBalones();
	
		barra->dibujarBarra(screen, juego, intercom);
		
		crearElemento();
		
		// contador de ciclos
		
		int clicos_mostrar = juego->getCiclos() - juego->getCiclos() % 10;
		char tmpuntos[10];
		sprintf (tmpuntos, "%d", clicos_mostrar);
		fuente->escribirTexto(screen, 0, ALIGN_LEFT, VALIGN_TOP, 12, tmpuntos, 255, 255, 255, 0, 0, 0, 10, 10);
		
		comprobarScreenShot();
		
		SDL_Flip (screen);
	} else {
		if ( (frameCartelMostrar>1) && (frameCartelMostrar<6) ) {
			juego->addCiclos();
			if (juego->getCiclos()%20==0) {
				if (frameCartelMostrar==5) {
					frameCartelMostrar = -1;
				} else {
					SDL_Rect clip_cartel = { 70, 130, 392, 156 };
					SDL_SetClipRect (screen, &clip_cartel);
					frameCartelMostrar++;
					cartelComoJugar->selFrame(frameCartelMostrar);
					cartelComoJugar->dibujar(screen);
					SDL_Flip (screen);
				}
			}
		}
		Uint8 *keys = SDL_GetKeyState (NULL);
		if (keys[SDLK_SPACE]) {
			frameCartelMostrar = -1;
			juego->setHacerClip(0);
		}
	}
	
}

void Pantalla::EscenaFinal () {

	if (final+40 > getCiclos()) { // cerrar compuertas
		mapa->dibujarMapa(screen);
		if (mitadLogoAbajo->getY()>240)
			mitadLogoAbajo->mover();
		if (mitadLogoArriba->getY()<0)
			mitadLogoArriba->mover();
		mitadLogoAbajo->dibujar(screen);
		mitadLogoArriba->dibujar(screen);
		
		barra->dibujarBarra(screen, juego, intercom);

		if (final+39 == getCiclos()) {
			enVSFinal = true;
			cargarVS(); // comenzamos el previo final
			//sonido->empezarMusica(MUS_FINAL1);
		}
	} else {
		if (enVSFinal) {
			int r = intro->DrawAnimation();
			if (r==1) {
				// empieza la fiesta
				enVSFinal = false;
				enFinal = true;
				empezarMusicaFinal();
				cargarMitadVersus();
				sonido->playSonido(SND_COMP_ABRIR);
			}
		}
		if (enFinal) {
	
			if (getSalirFase()>0) { // si estamos saliendo de fase
				
				// CARGAMOS Y PINTAMOS DIARIO
				if (juego->getCiclos() == getSalirFase() + 130) { // cargamos diario
					cargarDiario();
				}
				
				if (juego->getCiclos() >= getSalirFase() + 130) { // pintando diario
					SDL_SetClipRect (screen, NULL);
					int r = diario->DrawAnimation();
					if (r==1) {
						if (juego->getNivel()>=3) {
							setVolverAOpciones(true);	
							return;
						} else {
							Mix_HaltChannel(-1);
							initSpriteNivel(juego->getNivel()+1);
							Mix_HaltChannel(-1);
							iniciarPantalla();
							getJuego()->establecerContinue();
							getJuego()->setZonaSobrepasada(0);
							empezarMusicaFase();
							return;
						}
					}
					juego->setHacerClip(0);
				} else { // sino pintamos diario, pintamos el final de fase
					dibujarFinal();
				}
				
				if (juego->getCiclos() == getSalirFase() + 60) { // sacamos al jugador
					jugador->setFantasma(1);
					jugador->setEstado(4);
				}
				
				// BAJAMOS MUSICA Y PINTAMOS COMPUERTAS
				
				if (juego->getCiclos() == getSalirFase() + 100) { // bajamos musica
					sonido->terminarMusica();
					sonido->terminarMusicaSecundaria();
					mitadLogoAbajo->setY(480);
					mitadLogoAbajo->setDY(-20);
					mitadLogoArriba->setY(-240);
					mitadLogoArriba->setDY(20);
					sonido->playSonido(SND_COMP_CERRAR);
				}
				
				if ( (juego->getCiclos() > getSalirFase() + 100) &&
					(juego->getCiclos() < getSalirFase() + 130) ){
					if (mitadLogoAbajo->getY()>240)
						mitadLogoAbajo->mover();
					if (mitadLogoArriba->getY()<0)
						mitadLogoArriba->mover();
					mitadLogoAbajo->dibujar(screen);
					mitadLogoArriba->dibujar(screen);
					
					barra->dibujarBarra(screen, juego, intercom);
				}
				
			} else { // si no estamos en salir de final de fase
				dibujarFinal ();
			}
		}
	}
	/*
	if (juego->getHacerClip()) {
		SDL_SetClipRect (screen, &clip_recortado);
	} else {
		SDL_SetClipRect (screen, NULL);
		juego->setHacerClip(1);
	}
	*/
	SDL_Flip (screen);
}


void Pantalla::EscenaEnPausa () {
	
	negro->dibujar(screen);
	caja->dibujar(screen);
	txtPausa->dibujar(screen);

	SDL_SetClipRect (screen, NULL);
	
	SDL_Flip (screen);
}

void Pantalla::EscenaEnSel_Poder () {
	
	dibujarImg();	
	
	fondo_SelPoder->dibujar(screen);

	poderEscudo->selFrame(0);
	poderBomba->selFrame(0);
	poderClonacion->selFrame(0);
	poderCadista->selFrame(0);
	
	switch (juego->getPoderSel()) {
		case 1:
			poderEscudo->selFrame(1);
		break;
		case 2:
			poderBomba->selFrame(1);
		break;
		case 3:
			poderClonacion->selFrame(1);
		break;
		case 4:
			poderCadista->selFrame(1);
		break;
	}
	
	poderEscudo->dibujar(screen);
	poderBomba->dibujar(screen);
	poderClonacion->dibujar(screen);
	poderCadista->dibujar(screen);
	
	dibujarBarra();

	SDL_SetClipRect (screen, NULL);
	
	SDL_Flip (screen);
}

void Pantalla::EscenaEnGameOver (int est) {

	if (auxEstadoSalirPartida != est) {

		dibujarImg();
		
		caja->dibujar(screen);
		
		txtContinuar->dibujar(screen);
		
		if (est==0) {
			txtSi->selFrame(0);
			txtNo->selFrame(1);
		} else {
			txtSi->selFrame(1);
			txtNo->selFrame(0);
		}
		txtSi->dibujar(screen);
		txtNo->dibujar(screen);
	
		SDL_Flip (screen);
		auxEstadoSalirPartida = est;
	}

}


void Pantalla::EscenaEnMensaje () {
	
	dibujarImg();
	
	caja->dibujar(screen);
	
	txtMensajeFinal->dibujar(screen);
	
	txtFracasada->dibujar(screen);

	SDL_Flip (screen);

}


void Pantalla::EscenaEnRecord (char tmpnom[50] ) {

	char tmprecord[30] = "Nuevo record";
	char tmpcol[30] = "Inserte su nombre";
	
	dibujarImg();
	
	caja->dibujar(screen);
	
	fuente->escribirTexto(screen, 0, ALIGN_CENTER, VALIGN_CENTER, 20, tmprecord, 255, 230, 23, 62, 102, 157, screen_w/2, 190);
	fuente->escribirTexto(screen, 0, ALIGN_CENTER, VALIGN_CENTER, 17, tmpcol, 255, 255, 255, 62, 102, 157, screen_w/2, 220);
	fuente->escribirTexto(screen, 0, ALIGN_CENTER, VALIGN_CENTER, 22, tmpnom, 255, 255, 255, 62, 102, 157, screen_w/2, 280);
	SDL_Flip (screen);

}

void Pantalla::EscenaEnSalirPartida (int est) {
	if (auxEstadoSalirPartida != est) {
		
		dibujarImg();
		
		caja->dibujar(screen);
		
		txtSalir->dibujar(screen);
		if (est==0) {
			txtSi->selFrame(0);
			txtNo->selFrame(1);
		} else {
			txtSi->selFrame(1);
			txtNo->selFrame(0);
		}
		txtSi->dibujar(screen);
		txtNo->dibujar(screen);
		
		SDL_Flip (screen);
		auxEstadoSalirPartida = est;
	}
}

bool Pantalla::EscenaEnIntercom () {
	int salida = intercom->dibujarAnimacion();
	SDL_SetClipRect (screen, NULL);
	SDL_Flip (screen);
	return salida;
}


void Pantalla::dibujarNubes() {
	if (juego->getNivel()==1) {
		switch (juego->getCiclos()) {
			case 2300:
				tiempo->playNubes();
			break;
		}
		tiempo->dibujarNubes(screen);
	}
}

void Pantalla::dibujarElTiempo() {
	switch (juego->getNivel()) {
		case 1:
			switch (juego->getCiclos()) {
				case 150:
					tiempo->playNiebla();
				break;
				case 3800:
					tiempo->playNiebla();
				break;
			}		
		break;
		case 2:
			switch (juego->getCiclos()) {
				case 1300:
					tiempo->playNiebla();
				break;
			}	
		break;
		case 3:
			switch (juego->getCiclos()) {
				case 2400:
					tiempo->playCarnaval();
				break;
				case 3150:
					tiempo->stopCarnaval();
				break;
			}		
		break;
	}
	
	tiempo->dibujarNiebla(screen);
	tiempo->dibujarNieve(screen);
	tiempo->dibujarLluvia(screen);
	tiempo->dibujarCarnaval(screen);
}

void Pantalla::eliminarEnemigosPantalla() {
// descargar sprites
	int i, imp;
	
	//******************************************
	// ELIMINAR ENEMIGOS DE LA FASE 1
	//******************************************
	
	if (juego->getNivel()==1) {
		for (i=0; i < MAXENE_MARINOS; i++) {
			if (cangrejo[i]->getActivo() == 1) {
				imp = cangrejo[i]->addImpactosParaMorir(sonido, juego, explosiones);
				if (imp>0) {
					imp = cangrejo[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = cangrejo[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
			}
		}
		
		for (i=0; i < MAXENE_AUTOMARINO; i++) {
			if (lancha[i]->getActivo() == 1) {
				lancha[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
		
		for (i=0; i < MAXENE_CONSTRUCCIONES; i++) {
			if (caseta[i]->getActivo() == 1) {
				caseta[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
	} // enemigos de nivel 1

	
	//******************************************
	// ELIMINAR ENEMIGOS DE LA FASE 3
	//******************************************
	
	if (juego->getNivel()==3) {
		
		for (i=0; i < MAXENE_CSIMPLE; i++) {
			if (csimple[i]->getActivo() == 1) {
				imp = csimple[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
		
		for (i=0; i < MAXENE_TAXI; i++) {
			if (taxi[i]->getActivo() == 1) {
				imp = taxi[i]->addImpactosParaMorir(sonido, juego, explosiones);
				if (imp>0) {
					imp = taxi[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = taxi[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
			}
		}
		
		for (i=0; i < MAXENE_TANQUE; i++) {
			if (tanque[i]->getActivo() == 1) {
				imp = tanque[i]->addImpactosParaMorir(sonido, juego, explosiones);
				if (imp>0) {
					imp = tanque[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = tanque[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = tanque[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
			}
		}
		
		for (i=0; i < MAXENE_CARROZAS; i++) {
			if (carroza[i]->getActivo() == 1) {
				imp = carroza[i]->addImpactosParaMorir(sonido, juego, explosiones);
				if (imp>0) {
					imp = carroza[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = carroza[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = carroza[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = carroza[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = carroza[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
			}
		}
		
	} // final enemigos fase 3
	
	//******************************************
	// ELIMINAR ENEMIGOS DE LA FASE 2
	//******************************************
	
	if (juego->getNivel()==2) {
		for (i=0; i < MAXENE_CSIMPLE; i++) {
			if (csimple[i]->getActivo() == 1) {
				imp = csimple[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
		
		for (i=0; i < MAXENE_TAXI; i++) {
			if (taxi[i]->getActivo() == 1) {
				imp = taxi[i]->addImpactosParaMorir(sonido, juego, explosiones);
				if (imp>0) {
					imp = taxi[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = taxi[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
			}
		}
		
		for (i=0; i < MAXENE_TANQUE; i++) {
			if (tanque[i]->getActivo() == 1) {
				imp = tanque[i]->addImpactosParaMorir(sonido, juego, explosiones);
				if (imp>0) {
					imp = tanque[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = tanque[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = tanque[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
			}
		}
		
		for (i=0; i < MAXENE_MARINOS; i++) {
			if (cangrejo[i]->getActivo() == 1) {
				imp = cangrejo[i]->addImpactosParaMorir(sonido, juego, explosiones);
				if (imp>0) {
					imp = cangrejo[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = cangrejo[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
			}
			if (pulpo[i]->getActivo() == 1) {
				imp = pulpo[i]->addImpactosParaMorir(sonido, juego, explosiones);
				if (imp>0) {
					imp = pulpo[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = pulpo[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
			}
		}
		
		for (i=0; i < MAXENE_YATE; i++) {
			if (yate[i]->getActivo() == 1) {
				imp = yate[i]->addImpactosParaMorir(sonido, juego, explosiones);
				if (imp>0) {
					imp = yate[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = yate[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
			}
		}
		
		for (i=0; i < MAXENE_CONCHA; i++) {
			if (concha[i]->getActivo() == 1) {
				imp = concha[i]->addImpactosParaMorir(sonido, juego, explosiones);
				if (imp>0) {
					imp = concha[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
				if (imp>0) {
					imp = concha[i]->addImpactosParaMorir(sonido, juego, explosiones);
				}
			}
		}
		
	}// final fase 2
	
	for (i=0; i < MAXENE_GEN1; i++) {
		if (gaviotas[i]->getActivo() == 1) {
			gaviotas[i]->addImpactosParaMorir(sonido, juego, explosiones);
		}
		if (gaviotas2[i]->getActivo() == 1) {
			gaviotas2[i]->addImpactosParaMorir(sonido, juego, explosiones);
		}
		if (navepeq[i]->getActivo() == 1) {
			navepeq[i]->addImpactosParaMorir(sonido, juego, explosiones);
		}
		if (helicoptero[i]->getActivo() == 1) {
			helicoptero[i]->addImpactosParaMorir(sonido, juego, explosiones);
		}
	}
	
	for (i=0; i < MAXENE_GEN2; i++) {
		if (navemed[i]->getActivo() == 1) {
			imp = navemed[i]->addImpactosParaMorir(sonido, juego, explosiones);
			if (imp>0) {
				imp = navemed[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
			if (imp>0) {
				imp = navemed[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
		if (gavibot[i]->getActivo() == 1) {
			gavibot[i]->addImpactosParaMorir(sonido, juego, explosiones);
			if (imp>0) {
				imp = gavibot[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
			if (imp>0) {
				imp = gavibot[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
		if (avispa[i]->getActivo() == 1) {
			avispa[i]->addImpactosParaMorir(sonido, juego, explosiones);
			if (imp>0) {
				imp = avispa[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
			if (imp>0) {
				imp = avispa[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
	}
	
	for (i=0; i < MAXENE_GEN3; i++) {
		if (navegrande[i]->getActivo() == 1) {
			imp = navegrande[i]->addImpactosParaMorir(sonido, juego, explosiones);
			if (imp>0) {
				imp = navegrande[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
			if (imp>0) {
				imp = navegrande[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
			if (imp>0) {
				imp = navegrande[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
			if (imp>0) {
				imp = navegrande[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
		if (navezepelin[i]->getActivo() == 1) {
			navezepelin[i]->addImpactosParaMorir(sonido, juego, explosiones);
			if (imp>0) {
				imp = navezepelin[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
			if (imp>0) {
				imp = navezepelin[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
			if (imp>0) {
				imp = navezepelin[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
			if (imp>0) {
				imp = navezepelin[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
		if (naverascasio[i]->getActivo() == 1) {
			naverascasio[i]->addImpactosParaMorir(sonido, juego, explosiones);
			if (imp>0) {
				imp = naverascasio[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
			if (imp>0) {
				imp = naverascasio[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
			if (imp>0) {
				imp = naverascasio[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
			if (imp>0) {
				imp = naverascasio[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
	}
	
	disp_ene->iniciar();	
}

void Pantalla::dibujarAgregadores() {
	int i;
	for ( i=0; i<MAXAGREGADORES; i++ ) {
		if (agregadores[i]->getActivo() == 1) {
			agregadores[i]->mover();
			agregadores[i]->dibujar(screen);
		}
	}
}

void Pantalla::crearChispa(float x, float y) {
	// activamos la chispita
	int numLibre = elementoLibre(CHISPA);
	if ( numLibre != -1) {
		chispas[numLibre]->setActivo(1);
		chispas[numLibre]->selFrame(0);
		chispas[numLibre]->setX(x);
		chispas[numLibre]->setY(y);
	}
}

void Pantalla::dibujarChispas() {
	int i;
	for ( i=0; i<MAX_CHISPAS; i++ ) {
		if (chispas[i]->getActivo() == 1) {
				if (chispas[i]->getActualFrame()<2) {
					chispas[i]->selSiguienteFrame();
				} else {
					chispas[i]->setActivo(0);
					chispas[i]->selFrame(2);
				}
			chispas[i]->addY(-5);
			chispas[i]->dibujar(screen);
		}
	}
}


void Pantalla::comprobarScreenShot() {

	// cosultamos el teclado
	keys = SDL_GetKeyState (NULL);
	
	if (keys[SDLK_s]) { 
		char tmpch[127];
		sprintf(tmpch, "%s/screenshot%d.bmp", getConfiguracion()->getDirectorio(), nScreenShot);
		SDL_SaveBMP(screen, tmpch);
		nScreenShot++;
	}
	
}

void Pantalla::crearAgregador(int ta, int x, int y) {
	int numLibre = elementoLibre (AGREGADOR);
	if (numLibre != -1) {
		agregadores[numLibre]->setTipo(ta);
		agregadores[numLibre]->setAgX(x);
		agregadores[numLibre]->setAgY(y);
		agregadores[numLibre]->setActivo(1);
	}
}

void Pantalla::crearAgregador(int ta, int x, int y, int dx, int dy) {
	int numLibre = elementoLibre (AGREGADOR);
	if (numLibre != -1) {
		agregadores[numLibre]->setTipo(ta);
		agregadores[numLibre]->setAgX(x);
		agregadores[numLibre]->setAgY(y);
		agregadores[numLibre]->setAgDX(dx);
		agregadores[numLibre]->setAgDY(dy);
		agregadores[numLibre]->setActivo(1);
		agregadores[numLibre]->setAgCiclos(13);
	}
}

void Pantalla::comprobarColisiones() {
	int i,j;
	DisparoJugador* disp_jugador = jugador->getDisparoJugador();
	
	//******************************************
	// COLISIONES CON ENEMIGOS DE LA FASE 1
	//******************************************
	
	if (juego->getNivel() == 1) {
		
		// comprobar colisiones de balas con cangrebot
		for ( i=0; i < MAXENE_MARINOS; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!cangrejo[i]->getFantasma() && (cangrejo[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo()) ) {
					if ( cangrejo[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) {
						// restar impactos para morir y eliminar bala de pantalla
						cangrejo[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!cangrejo[i]->getFantasma() && (cangrejo[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( cangrejo[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							cangrejo[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
	
		// comprobar colisiones de balas con lancha
		for ( i=0; i < MAXENE_AUTOMARINO; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!lancha[i]->getFantasma() && (lancha[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( lancha[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						lancha[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!lancha[i]->getFantasma() && (lancha[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( lancha[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							lancha[i]->addImpactosParaMorir(sonido, juego, explosiones);
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}	
		
		// comprobar colisiones de balas con caseta
		for ( i=0; i < MAXENE_CONSTRUCCIONES; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!caseta[i]->getFantasma() && (caseta[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( caseta[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						caseta[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!caseta[i]->getFantasma() && (caseta[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( caseta[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							caseta[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}	

		// comprobar colision de balas con minas
		for (i=0; i < MAXENE_MINA; i++) {
			for (j=0; j < MAXBALAS; j++) {
				if (!mina[i]->getFantasma()  && (mina[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( mina[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						disp_jugador->getDisparo(j)->setActivo(0);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!mina[i]->getFantasma() && (mina[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( mina[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							disp_jugador->getBalon(j)->setActivo(0);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						}
					}
				}
			}
		}
		
		// comprobar colisiones de jugador con minas
		for ( i=0; i < MAXENE_MINA; i++) {
			if (!mina[i]->getFantasma() && (mina[i]->getActivo()) && (jugador->getEstado() == 2 )  && (jugador->getFantasma() !=1)  ) {
				if (( mina[i]->colision(jugador) == TRUE ) ) {
					morirJugador();
				}
			}
		}
		
		// comprobar colisiones de balas con torres		
		if (final>0) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!torrebal_der->getFantasma() && (torrebal_der->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( torrebal_der->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						torrebal_der->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!torrebal_der->getFantasma() && (torrebal_der->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( torrebal_der->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							torrebal_der->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
			
			for ( j=0; j < MAXBALAS; j++) {
				if (!torrebal_izq->getFantasma() && (torrebal_izq->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( torrebal_izq->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						torrebal_izq->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!torrebal_izq->getFantasma() && (torrebal_izq->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( torrebal_izq->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							torrebal_izq->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
			
		}
		
		
	}	// FINALIZADO COMPROBACION DE FASE 1
	
	//******************************************
	// COLISIONES CON ENEMIGOS DE LA FASE 3
	//******************************************
	
	if (juego->getNivel() == 3) {
		
		// comprobar colisiones de balas con policia
		for ( i=0; i < MAXENE_CPOLICIA; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!cpolicia[i]->getFantasma() && (cpolicia[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( cpolicia[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						cpolicia[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!cpolicia[i]->getFantasma() && (cpolicia[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( cpolicia[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							cpolicia[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
		
		// comprobar colisiones de balas con tanque
		for ( i=0; i < MAXENE_TANQUE; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!tanque[i]->getFantasma() && (tanque[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( tanque[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						tanque[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!tanque[i]->getFantasma() && (tanque[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( tanque[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							tanque[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
		
		
		// comprobar colisiones de balas con taxi
		for ( i=0; i < MAXENE_TAXI; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!taxi[i]->getFantasma() && (taxi[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( taxi[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						taxi[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!taxi[i]->getFantasma() && (taxi[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( taxi[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							taxi[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
		
		// comprobar colisiones de balas con coches simples
		for ( i=0; i < MAXENE_CSIMPLE; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!csimple[i]->getFantasma() && (csimple[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( csimple[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						csimple[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!csimple[i]->getFantasma() && (csimple[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( csimple[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							csimple[i]->addImpactosParaMorir(sonido, juego, explosiones);
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
		
		// comprobar colisiones de balas con carrozas
		for ( i=0; i < MAXENE_CARROZAS; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!carroza[i]->getFantasma() && (carroza[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( carroza[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						//carroza[i]->addImpactosParaMorir(sonido, juego, explosiones);
						if  ( carroza[i]->addImpactosParaMorir(sonido, juego, explosiones) <= 0 ) {
							if (carroza[i]->getTipoRegalo() != AG_NONE ) {
								crearAgregador(carroza[i]->getTipoRegalo(), carroza[i]->getCentroX(), carroza[i]->getCentroY());
							}
						}
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!carroza[i]->getFantasma() && (carroza[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( carroza[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							if  ( carroza[i]->addImpactosParaMorir(sonido, juego, explosiones) <= 0 ) {
								if (carroza[i]->getTipoRegalo() != AG_NONE ) {
									crearAgregador(carroza[i]->getTipoRegalo(), carroza[i]->getCentroX(), carroza[i]->getCentroY());
								}
							}
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
		
		// comprobar colisiones de balas con barreras
		for ( i=0; i < MAXENE_BARRERAS; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!valla_der[i]->getFantasma() && (valla_der[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( valla_der[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						valla_der[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!valla_der[i]->getFantasma() && (valla_der[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( valla_der[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							valla_der[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
			
			for ( j=0; j < MAXBALAS; j++) {
				if (!valla_izq[i]->getFantasma() && (valla_izq[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( valla_izq[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						valla_izq[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!valla_izq[i]->getFantasma() && (valla_izq[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( valla_izq[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							valla_izq[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
			
			for ( j=0; j < MAXBALAS; j++) {
				if (!barrera_der[i]->getFantasma() && (barrera_der[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( barrera_der[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						barrera_der[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!barrera_der[i]->getFantasma() && (barrera_der[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( barrera_der[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							barrera_der[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
			
			for ( j=0; j < MAXBALAS; j++) {
				if (!barrera_izq[i]->getFantasma() && (barrera_izq[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( barrera_izq[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						barrera_izq[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!barrera_izq[i]->getFantasma() && (barrera_izq[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( barrera_izq[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							barrera_izq[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
			
			
		}
		
		
		if (final>0) {
			// comprobar colisiones de balas con jefes3
			for ( i=0; i < 3; i++) {
				for ( j=0; j < MAXBALAS; j++) {
					if (!jefe3[i]->getFantasma() && (jefe3[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
						if (( jefe3[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							//carroza[i]->addImpactosParaMorir(sonido, juego, explosiones);
							jefe3[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getDisparo(j)->setActivo(0);
						}
					}
				}
				if (EnPoderCadista) {
					for ( j=0; j < MAX_BALON; j++) {
						if (!jefe3[i]->getFantasma() && (jefe3[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
							if (( jefe3[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
								// restar impactos para morir y eliminar bala de pantalla
								jefe3[i]->addImpactosParaMorir(sonido, juego, explosiones);
								crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
								disp_jugador->getBalon(j)->setActivo(0);
							}
						}
					}
				}
				
			}
			
			// comprobar colisiones de jugador con jefes2
			for ( i=0; i < 3; i++) {
				if (!jefe3[i]->getFantasma() && (jefe3[i]->getActivo()) && (jugador->getEstado() == 2 )  && (jugador->getFantasma() !=1)  ) {
					if (( jefe3[i]->colision(jugador) == TRUE ) ) {
						morirJugador();
					}
				}
			}
			
			// comprobar colisiones de balas con biopic
			for ( j=0; j < MAXBALAS; j++) {
				if (!biopic->getFantasma() && (biopic->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( biopic->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!biopic->getFantasma() && (biopic->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( biopic->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
			
			// comprobar colisiones de jugador con biopic
			
			if (!biopic->getFantasma() && (biopic->getActivo()) && (jugador->getEstado() == 2 )  && (jugador->getFantasma() !=1)  ) {
				if (( biopic->colision(jugador) == TRUE ) ) {
					morirJugador();
				}
			}
		}
		
	} // FINALIZADO COMPROBACION DE FASE 3
	
	
	//******************************************
	// COLISIONES CON ENEMIGOS DE LA FASE 2
	//******************************************
	
	if (juego->getNivel() == 2) {
		
		// comprobar colisiones de balas con cangrebot
		for ( i=0; i < MAXENE_MARINOS; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!cangrejo[i]->getFantasma() && (cangrejo[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( cangrejo[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						cangrejo[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
				if (!pulpo[i]->getFantasma() && (pulpo[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( pulpo[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						pulpo[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!cangrejo[i]->getFantasma() && (cangrejo[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( cangrejo[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							cangrejo[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
					if (!pulpo[i]->getFantasma() && (pulpo[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( pulpo[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							pulpo[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
	
		// comprobar colisiones de balas con lancha
		for ( i=0; i < MAXENE_AUTOMARINO; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!lancha[i]->getFantasma() && (lancha[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( lancha[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						lancha[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!lancha[i]->getFantasma() && (lancha[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( lancha[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							lancha[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}	
		
		// comprobar colisiones de balas con yate
		for ( i=0; i < MAXENE_YATE; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!yate[i]->getFantasma() && (yate[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( yate[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						yate[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!yate[i]->getFantasma() && (yate[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( yate[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							yate[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
		
		// comprobar colisiones de balas con policia
		for ( i=0; i < MAXENE_CPOLICIA; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!cpolicia[i]->getFantasma() && (cpolicia[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( cpolicia[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						cpolicia[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!cpolicia[i]->getFantasma() && (cpolicia[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( cpolicia[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							cpolicia[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
		
		// comprobar colisiones de balas con concha
		for ( i=0; i < MAXENE_CONCHA; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!concha[i]->getFantasma() && (concha[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( concha[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						concha[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!concha[i]->getFantasma() && (concha[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( concha[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							concha[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
		
		// comprobar colisiones de balas con tanque
		for ( i=0; i < MAXENE_TANQUE; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!tanque[i]->getFantasma() && (tanque[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( tanque[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						tanque[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!tanque[i]->getFantasma() && (tanque[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( tanque[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							tanque[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
		
		
		// comprobar colisiones de balas con taxi
		for ( i=0; i < MAXENE_TAXI; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!taxi[i]->getFantasma() && (taxi[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( taxi[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						taxi[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!taxi[i]->getFantasma() && (taxi[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( taxi[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							taxi[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
		
		// comprobar colisiones de balas con coches simples
		for ( i=0; i < MAXENE_CSIMPLE; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!csimple[i]->getFantasma() && (csimple[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( csimple[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						csimple[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!csimple[i]->getFantasma() && (csimple[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( csimple[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							csimple[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
		}
		
		// comprobar colisiones de balas con barreras
		for ( i=0; i < MAXENE_BARRERAS; i++) {
			for ( j=0; j < MAXBALAS; j++) {
				if (!valla_der[i]->getFantasma() && (valla_der[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( valla_der[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						valla_der[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!valla_der[i]->getFantasma() && (valla_der[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( valla_der[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							valla_der[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
			
			for ( j=0; j < MAXBALAS; j++) {
				if (!valla_izq[i]->getFantasma() && (valla_izq[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( valla_izq[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						valla_izq[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!valla_izq[i]->getFantasma() && (valla_izq[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( valla_izq[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							valla_izq[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
			
			for ( j=0; j < MAXBALAS; j++) {
				if (!barrera_der[i]->getFantasma() && (barrera_der[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( barrera_der[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						barrera_der[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!barrera_der[i]->getFantasma() && (barrera_der[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( barrera_der[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							barrera_der[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
			
			for ( j=0; j < MAXBALAS; j++) {
				if (!barrera_izq[i]->getFantasma() && (barrera_izq[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
					if (( barrera_izq[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						barrera_izq[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getDisparo(j)->setActivo(0);
					}
				}
			}
			if (EnPoderCadista) {
				for ( j=0; j < MAX_BALON; j++) {
					if (!barrera_izq[i]->getFantasma() && (barrera_izq[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
						if (( barrera_izq[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
							// restar impactos para morir y eliminar bala de pantalla
							barrera_izq[i]->addImpactosParaMorir(sonido, juego, explosiones);
							crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
							disp_jugador->getBalon(j)->setActivo(0);
						}
					}
				}
			}
			
		}
		
		
	} // FINALIZADO COMPROBACION DE FASE 2
	
	
	// comprobar colisiones de jugador con agregadores
	for ( i=0; i < MAXAGREGADORES; i++) {
		if (!agregadores[i]->getFantasma()  && (agregadores[i]->getActivo())  ) { // && (jugador->getEstado() == 2 ) 
			if (( agregadores[i]->colision(jugador) == TRUE )) {
				switch (agregadores[i]->getTipo()) {
					case AG_PODER:
						juego->addBarraPoder();
						if (juego->getBarraPoder()>=3) {
							juego->addPoderes();
							switch(rand()%3) {
								case 0:
									sonido->playSonido(SND_ENERGIATOPE0);
								break;
								case 1:
									sonido->playSonido(SND_ENERGIATOPE1);
								break;
								case 2:
									sonido->playSonido(SND_ENERGIATOPE2);
								break;
							}
						} else {
							sonido->playSonido(SND_AG_PODER);
						}
					break;
					case AG_VIDA:
						juego->addVidas();
						sonido->playSonido(SND_AG_VIDA);
					break;
					case AG_DISPARO:
						juego->addTipoDisparo();
						if (juego->getTipoDisparo() == 1) {
							sonido->playSonido(SND_AG_DISPARO_LASER);
						} else if (juego->getTipoDisparo() == 2) {
							sonido->playSonido(SND_AG_DISPARO_TRIPLE);
						} 
					break;
				}
				agregadores[i]->iniciar();
			}
		}
	}
	
	// comprobar balas de los enemigos con el jugador
	if ( ( disp_ene->colisionConJugador() ) && (jugador->getFantasma() !=1) ) {
		if (!juego->getPoderActivo()){
			morirJugador();
		} else {
			if (juego->getPoderSel() != 1)  {
				morirJugador();
			}
		}
	}	
	
	// comprobar colosion de balas del jugador con balas de enemigos
	
	for (i=0; i < MAXBALAS; i++) {
		disp_ene->colisionConDisparosJugador(disp_jugador->getDisparo(i), explosiones, sonido);
	}
	
	// comprobar colision de balas con gaviotas
	for (i=0; i < MAXENE_GEN1; i++) {
		for (j=0; j < MAXBALAS; j++) {
			if (!gaviotas[i]->getFantasma()  && (gaviotas[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
				if (( gaviotas[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
					// restar impactos para morir y eliminar bala de pantalla
					gaviotas[i]->addImpactosParaMorir(sonido, juego, explosiones);
					disp_jugador->getDisparo(j)->setActivo(0);
				}
			}
		}
		if (EnPoderCadista) {
			for ( j=0; j < MAX_BALON; j++) {
				if (!gaviotas[i]->getFantasma() && (gaviotas[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
					if (( gaviotas[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						gaviotas[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getBalon(j)->setActivo(0);
					}
				}
			}
		}
	}
	
	// comprobar colisiones de balas con gaviotas2
	for (i=0; i < MAXENE_GEN1; i++) {
		for (j=0; j < MAXBALAS; j++) {
			if (!gaviotas2[i]->getFantasma()  && (gaviotas2[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
				if (( gaviotas2[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
					// restar impactos para morir y eliminar bala de pantalla
					gaviotas2[i]->addImpactosParaMorir(sonido, juego, explosiones);
					disp_jugador->getDisparo(j)->setActivo(0);
				}
			}
		}
		if (EnPoderCadista) {
			for ( j=0; j < MAX_BALON; j++) {
				if (!gaviotas2[i]->getFantasma() && (gaviotas2[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
					if (( gaviotas2[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						gaviotas2[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getBalon(j)->setActivo(0);
					}
				}
			}
		}
	}

	// comprobar colisiones de balas con nave pequeña
	for (i=0; i < MAXENE_GEN1; i++) {
		for (j=0; j < MAXBALAS; j++) {
			if (!navepeq[i]->getFantasma()  && (navepeq[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
				if (( navepeq[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
					// restar impactos para morir y eliminar bala de pantalla
					navepeq[i]->addImpactosParaMorir(sonido, juego, explosiones);
					disp_jugador->getDisparo(j)->setActivo(0);
				}
			}
		}
		if (EnPoderCadista) {
			for ( j=0; j < MAX_BALON; j++) {
				if (!navepeq[i]->getFantasma() && (navepeq[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
					if (( navepeq[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						navepeq[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getBalon(j)->setActivo(0);
					}
				}
			}
		}
	}
	
	// comprobar colisiones de balas con el helicoptero
	for (i=0; i < MAXENE_GEN1; i++) {
		for (j=0; j < MAXBALAS; j++) {
			if (!helicoptero[i]->getFantasma()  && (helicoptero[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
				if (( helicoptero[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
					// restar impactos para morir y eliminar bala de pantalla
					helicoptero[i]->addImpactosParaMorir(sonido, juego, explosiones);
					disp_jugador->getDisparo(j)->setActivo(0);
				}
			}
		}
		if (EnPoderCadista) {
			for ( j=0; j < MAX_BALON; j++) {
				if (!helicoptero[i]->getFantasma() && (helicoptero[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
					if (( helicoptero[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						helicoptero[i]->addImpactosParaMorir(sonido, juego, explosiones);
						disp_jugador->getBalon(j)->setActivo(0);
					}
				}
			}
		}
	}

	// comprobar colisiones de balas con nave mediana
	for (i=0; i < MAXENE_GEN2; i++) {
		for (j=0; j < MAXBALAS; j++) {
			if (!navemed[i]->getFantasma()  && (navemed[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
				if (( navemed[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
					// restar impactos para morir y eliminar bala de pantalla
					navemed[i]->addImpactosParaMorir(sonido, juego, explosiones);
					crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
					disp_jugador->getDisparo(j)->setActivo(0);
				}
			}
		}
		if (EnPoderCadista) {
			for ( j=0; j < MAX_BALON; j++) {
				if (!navemed[i]->getFantasma() && (navemed[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
					if (( navemed[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						navemed[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getBalon(j)->setActivo(0);
					}
				}
			}
		}
	}
	
	// comprobar colisiones de balas con gavibot
	for (i=0; i < MAXENE_GEN2; i++) {
		for (j=0; j < MAXBALAS; j++) {
			if (!gavibot[i]->getFantasma()  && (gavibot[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
				if (( gavibot[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
					// restar impactos para morir y eliminar bala de pantalla
					gavibot[i]->addImpactosParaMorir(sonido, juego, explosiones);
					crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
					disp_jugador->getDisparo(j)->setActivo(0);
				}
			}
		}
		if (EnPoderCadista) {
			for ( j=0; j < MAX_BALON; j++) {
				if (!gavibot[i]->getFantasma() && (gavibot[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
					if (( gavibot[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						gavibot[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getBalon(j)->setActivo(0);
					}
				}
			}
		}
	}
	
	// comprobar colisiones de balas con avispa
	for (i=0; i < MAXENE_GEN2; i++) {
		for (j=0; j < MAXBALAS; j++) {
			if (!avispa[i]->getFantasma()  && (avispa[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
				if (( avispa[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
					// restar impactos para morir y eliminar bala de pantalla
					avispa[i]->addImpactosParaMorir(sonido, juego, explosiones);
					crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
					disp_jugador->getDisparo(j)->setActivo(0);
				}
			}
		}
		if (EnPoderCadista) {
			for ( j=0; j < MAX_BALON; j++) {
				if (!avispa[i]->getFantasma() && (avispa[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
					if (( avispa[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						avispa[i]->addImpactosParaMorir(sonido, juego, explosiones);
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getBalon(j)->setActivo(0);
					}
				}
			}
		}
	}
	
	// comprobar colisiones de balas con nave grande
	for ( i=0; i < MAXENE_GEN3; i++) {
		for ( j=0; j < MAXBALAS; j++) {
			if (!navegrande[i]->getFantasma() && (navegrande[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
				if (( navegrande[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
					// restar impactos para morir y eliminar bala de pantalla
					if ( navegrande[i]->addImpactosParaMorir(sonido, juego, explosiones) <= 0 )  {
						if (navegrande[i]->getTipoRegalo() != AG_NONE ) {
							crearAgregador(navegrande[i]->getTipoRegalo(), navegrande[i]->getCentroX(), navegrande[i]->getCentroY());
						}
						navegrande[i]->iniciar();
					}
					//navegrande[i]->addImpactosParaMorir(init, juego, explosiones);
					crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
					disp_jugador->getDisparo(j)->setActivo(0);
				}
			}
		}
		if (EnPoderCadista) {
			for ( j=0; j < MAX_BALON; j++) {
				if (!navegrande[i]->getFantasma() && (navegrande[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
					if (( navegrande[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						if ( navegrande[i]->addImpactosParaMorir(sonido, juego, explosiones) <= 0 )  {
							if (navegrande[i]->getTipoRegalo() != AG_NONE ) {
								crearAgregador(navegrande[i]->getTipoRegalo(), navegrande[i]->getCentroX(), navegrande[i]->getCentroY());
							}
							navegrande[i]->iniciar();
						}
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getBalon(j)->setActivo(0);
					}
				}
			}
		}
	}
	
	// comprobar colisiones de balas con nave zepelin
	for ( i=0; i < MAXENE_GEN3; i++) {
		for ( j=0; j < MAXBALAS; j++) {
			if (!navezepelin[i]->getFantasma() && (navezepelin[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
				if (( navezepelin[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
					// restar impactos para morir y eliminar bala de pantalla
					if  ( navezepelin[i]->addImpactosParaMorir(sonido, juego, explosiones) <= 0 ) {
						if (navezepelin[i]->getTipoRegalo() != AG_NONE ) {
							crearAgregador(navezepelin[i]->getTipoRegalo(), navezepelin[i]->getCentroX(), navezepelin[i]->getCentroY());
						}
						navezepelin[i]->iniciar();
					}
					crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
					disp_jugador->getDisparo(j)->setActivo(0);
				}
			}
		}
		if (EnPoderCadista) {
			for ( j=0; j < MAX_BALON; j++) {
				if (!navezepelin[i]->getFantasma() && (navezepelin[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
					if (( navezepelin[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						if ( navezepelin[i]->addImpactosParaMorir(sonido, juego, explosiones) <= 0 )  {
							if (navezepelin[i]->getTipoRegalo() != AG_NONE ) {
								crearAgregador(navezepelin[i]->getTipoRegalo(), navezepelin[i]->getCentroX(), navezepelin[i]->getCentroY());
							}
							navezepelin[i]->iniciar();
						}
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getBalon(j)->setActivo(0);
					}
				}
			}
		}
	}
	
	// comprobar colisiones de balas con nave rascasio
	for ( i=0; i < MAXENE_GEN3; i++) {
		for ( j=0; j < MAXBALAS; j++) {
			if (!naverascasio[i]->getFantasma() && (naverascasio[i]->getActivo()) && (disp_jugador->getDisparo(j)->getActivo())  ) {
				if (( naverascasio[i]->colision(disp_jugador->getDisparo(j)) == TRUE ) ){
					// restar impactos para morir y eliminar bala de pantalla
					if  ( naverascasio[i]->addImpactosParaMorir(sonido, juego, explosiones) <= 0 ) {
						if (naverascasio[i]->getTipoRegalo() != AG_NONE ) {
							crearAgregador(naverascasio[i]->getTipoRegalo(), naverascasio[i]->getCentroX(), naverascasio[i]->getCentroY());
						}
						naverascasio[i]->iniciar();
					}
					crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
					disp_jugador->getDisparo(j)->setActivo(0);
				}
			}
		}
		if (EnPoderCadista) {
			for ( j=0; j < MAX_BALON; j++) {
				if (!naverascasio[i]->getFantasma() && (naverascasio[i]->getActivo()) && (disp_jugador->getBalon(j)->getActivo())  ) {
					if (( naverascasio[i]->colision(disp_jugador->getBalon(j)) == TRUE ) ){
						// restar impactos para morir y eliminar bala de pantalla
						if ( naverascasio[i]->addImpactosParaMorir(sonido, juego, explosiones) <= 0 )  {
							if (naverascasio[i]->getTipoRegalo() != AG_NONE ) {
								crearAgregador(naverascasio[i]->getTipoRegalo(), naverascasio[i]->getCentroX(), naverascasio[i]->getCentroY());
							}
							naverascasio[i]->iniciar();
						}
						crearChispa(disp_jugador->getDisparo(j)->getX(), disp_jugador->getDisparo(j)->getY());
						disp_jugador->getBalon(j)->setActivo(0);
					}
				}
			}
		}
	}
	
	
	// comprobar colisiones de jugador con nave grande
	for ( i=0; i < MAXENE_GEN3; i++) {
		if (!navegrande[i]->getFantasma() && (navegrande[i]->getActivo()) && (jugador->getEstado() == 2 )   && (jugador->getFantasma() !=1) ) {
			if (( navegrande[i]->colision(jugador) == TRUE ) ) {
				navegrande[i]->addImpactosParaMorir(sonido, juego, explosiones);
				morirJugador();
			}
		}
	}

	// comprobar colisiones de jugador con nave zepelin
	for ( i=0; i < MAXENE_GEN3; i++) {
		if (!navezepelin[i]->getFantasma() && (navezepelin[i]->getActivo()) && (jugador->getEstado() == 2 )  && (jugador->getFantasma() !=1)  ) {
			if (( navezepelin[i]->colision(jugador) == TRUE ) ) {
				navezepelin[i]->addImpactosParaMorir(sonido, juego, explosiones);
				morirJugador();
			}
		}
	}
	
	// comprobar colisiones de jugador con nave rascasio
	for ( i=0; i < MAXENE_GEN3; i++) {
		if (!naverascasio[i]->getFantasma() && (naverascasio[i]->getActivo()) && (jugador->getEstado() == 2 )  && (jugador->getFantasma() !=1)  ) {
			if (( naverascasio[i]->colision(jugador) == TRUE ) ) {
				naverascasio[i]->addImpactosParaMorir(sonido, juego, explosiones);
				morirJugador();
			}
		}
	}
	
	// comprobar colisiones de jugador con nave mediana
	for ( i=0; i < MAXENE_GEN2; i++) {
		if (!navemed[i]->getFantasma() && (navemed[i]->getActivo()) && (jugador->getEstado() == 2 )  && (jugador->getFantasma() !=1)  ) {
			if (( navemed[i]->colision(jugador) == TRUE ) ) {
				navemed[i]->addImpactosParaMorir(sonido, juego, explosiones);
				morirJugador();
			}
		}
	}
	
	// comprobar colisiones de jugador con gavibots
	for ( i=0; i < MAXENE_GEN2; i++) {
		if (!gavibot[i]->getFantasma() && (gavibot[i]->getActivo()) && (jugador->getEstado() == 2 )  && (jugador->getFantasma() !=1)  ) {
			if (( gavibot[i]->colision(jugador) == TRUE ) ) {
				gavibot[i]->addImpactosParaMorir(sonido, juego, explosiones);
				morirJugador();
			}
		}
	}
	
	// comprobar colisiones de jugador con avispa
	for ( i=0; i < MAXENE_GEN2; i++) {
		if (!avispa[i]->getFantasma() && (avispa[i]->getActivo()) && (jugador->getEstado() == 2 )  && (jugador->getFantasma() !=1)  ) {
			if (( avispa[i]->colision(jugador) == TRUE ) ) {
				avispa[i]->addImpactosParaMorir(sonido, juego, explosiones);
				morirJugador();
			}
		}
	}
	
	
	// comprobar colisiones de jugador con helicoptero
	for ( i=0; i < MAXENE_GEN1; i++) {
		if (!helicoptero[i]->getFantasma()  && (helicoptero[i]->getActivo()) && (jugador->getEstado() == 2 )  && (jugador->getFantasma() !=1)  ) {
			if (( helicoptero[i]->colision(jugador) == TRUE ) ) {
				if (juego->getPoderActivo() ==0) {
					morirJugador();
				} else {
					if (juego->getPoderSel() != 1) {
						morirJugador();
					}
				}
				helicoptero[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
	}
	
	// comprobar colisiones de jugador con nave pequeña
	for ( i=0; i < MAXENE_GEN1; i++) {
		if (!navepeq[i]->getFantasma()  && (navepeq[i]->getActivo()) && (jugador->getEstado() == 2 )  && (jugador->getFantasma() !=1)  ) {
			if (( navepeq[i]->colision(jugador) == TRUE ) ) {
				if (juego->getPoderActivo() ==0) {
					morirJugador();
				} else {
					if (juego->getPoderSel() != 1) {
						morirJugador();
					}
				}
				navepeq[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
	}
	
	// comprobar colisiones de jugador con gaviota
	for ( i=0; i < MAXENE_GEN1; i++) {
		if (!gaviotas[i]->getFantasma()  && (gaviotas[i]->getActivo()) && (jugador->getEstado() == 2 ) && (jugador->getFantasma() !=1)  ) {
			if (( gaviotas[i]->colision(jugador) == TRUE ) ) {
				if (juego->getPoderActivo() ==0) {
					morirJugador();
				} else {
					if (juego->getPoderSel() != 1) {
						morirJugador();
					}
				}
				gaviotas[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
	}
	
	// comprobar colisiones de jugador con gaviota2
	for ( i=0; i < MAXENE_GEN1; i++) {
		if (!gaviotas2[i]->getFantasma()  && (gaviotas2[i]->getActivo()) && (jugador->getEstado() == 2 )  && (jugador->getFantasma() !=1)  ) {
			if (( gaviotas2[i]->colision(jugador) == TRUE )) {
				if (juego->getPoderActivo() ==0) {
					morirJugador();
				} else {
					if (juego->getPoderSel() != 1) {
						morirJugador();
					}
				}
				gaviotas2[i]->addImpactosParaMorir(sonido, juego, explosiones);
			}
		}
	}
	
}

void Pantalla::crearDisparoEnemigo () {
	int i, x, y;
	
	if (tiempoBloqueoDisparosEnemigos>0) {
		tiempoBloqueoDisparosEnemigos--;
	} else {

		//******************************************
		// DISPARAR ENEMIGOS DE LA FASE 1
		//******************************************
		
		if (juego->getNivel()==1) {
			for ( i=0; i<MAXENE_MARINOS; i++ ) {
				if ( ( cangrejo[i]->comprobarDisparo() ) && (cangrejo[i]->getActivo() == 1) ) {
					disp_ene->crearDisparo( cangrejo[i]->getTipo_Disparo(), cangrejo[i]->getMov_Disparo(), cangrejo[i]->getCentroX(), cangrejo[i]->getCentroY(), 0, 0);
				}
			}
		
			for ( i=0; i<MAXENE_AUTOMARINO; i++ ) {
				if ( ( lancha[i]->comprobarDisparo() ) && (lancha[i]->getActivo() == 1) ) {
					disp_ene->crearDisparo( lancha[i]->getTipo_Disparo(), lancha[i]->getMov_Disparo(), lancha[i]->getCentroX(), lancha[i]->getCentroY(), 0, 0);
				}
			}
			
			for ( i=0; i<MAXENE_CONSTRUCCIONES; i++ ) {
				if ( ( caseta[i]->comprobarDisparo() ) && (caseta[i]->getActivo() == 1) ) {
					disp_ene->crearDisparo( caseta[i]->getTipo_Disparo(), caseta[i]->getMov_Disparo(), caseta[i]->getCentroX(), caseta[i]->getCentroY(), 0, 0);
				}
			}
			if (final>0) {
				if ( ( torrebal_der->comprobarDisparo() ) && (torrebal_der->getActivo() == 1) ) {
					disp_ene->crearDisparo( torrebal_der->getTipo_Disparo(), torrebal_der->getMov_Disparo(), torrebal_der->getCentroX(), torrebal_der->getCentroY(), 0, 0);
				}
				
				if ( ( torrebal_izq->comprobarDisparo() ) && ( torrebal_izq->getActivo() == 1 ) ) {
					disp_ene->crearDisparo( torrebal_izq->getTipo_Disparo(), torrebal_izq->getMov_Disparo(), torrebal_izq->getCentroX(), torrebal_izq->getCentroY(), 0, 0);
				}
			}
			
		} // FINAL DISPAROS FASE 1
		
		//******************************************
		// DISPARAR ENEMIGOS DE LA FASE 3
		//******************************************
		
		if (juego->getNivel()==3) {
			for ( i=0; i<MAXENE_TANQUE; i++ ) {
				if ( ( tanque[i]->comprobarDisparo() ) && (tanque[i]->getActivo() == 1) ) {
					x = tanque[i]->getCentroX() + (int)(disp_ene->getCoseno(tanque[i]->getPosTorreta()*2)*55);
					y = tanque[i]->getCentroY() - (int)(disp_ene->getSeno(tanque[i]->getPosTorreta()*2)*55);
					disp_ene->crearDisparo( tanque[i]->getTipo_Disparo(), tanque[i]->getMov_Disparo(), x, y, 0, tanque[i]->getPosTorreta());
				}
			}
			for ( i=0; i<MAXENE_CARROZAS; i++ ) {
				if ( ( carroza[i]->comprobarDisparo() ) && (carroza[i]->getActivo() == 1) && (carroza[i]->getFantasma() == 0) ) {
					disp_ene->crearDisparo( carroza[i]->getTipo_Disparo(), carroza[i]->getMov_Disparo(), carroza[i]->getCentroX(), carroza[i]->getCentroY(), 0, 0);
				}
			}
		} // FINAL DISPAROS FASE 3
		
		//******************************************
		// DISPARAR ENEMIGOS DE LA FASE 2
		//******************************************
		
		if (juego->getNivel()==2) {
			for ( i=0; i<MAXENE_MARINOS; i++ ) {
				if ( ( cangrejo[i]->comprobarDisparo() ) && (cangrejo[i]->getActivo() == 1) ) {
					disp_ene->crearDisparo( cangrejo[i]->getTipo_Disparo(), cangrejo[i]->getMov_Disparo(), cangrejo[i]->getCentroX(), cangrejo[i]->getCentroY(), 0, 0);
				}
				if ( ( pulpo[i]->comprobarDisparo() ) && (pulpo[i]->getActivo() == 1) ) {
					disp_ene->crearDisparo( pulpo[i]->getTipo_Disparo(), pulpo[i]->getMov_Disparo(), pulpo[i]->getCentroX(), pulpo[i]->getCentroY(), 0, 0);
				}
			}
		
			for ( i=0; i<MAXENE_AUTOMARINO; i++ ) {
				if ( ( lancha[i]->comprobarDisparo() ) && (lancha[i]->getActivo() == 1) ) {
					disp_ene->crearDisparo( lancha[i]->getTipo_Disparo(), lancha[i]->getMov_Disparo(), lancha[i]->getCentroX(), lancha[i]->getCentroY(), 0, 0);
				}
			}
			
			for ( i=0; i<MAXENE_YATE; i++ ) {
				if ( ( yate[i]->comprobarDisparo() ) && (yate[i]->getActivo() == 1) ) {
					x = yate[i]->getCentroX() + (int)(disp_ene->getCoseno(yate[i]->getPosTorreta()*2)*10);
					y = yate[i]->getCentroY() - (int)(disp_ene->getSeno(yate[i]->getPosTorreta()*2)*10);
					disp_ene->crearDisparo( yate[i]->getTipo_Disparo(), yate[i]->getMov_Disparo(), x, y, 0, yate[i]->getPosTorreta());
				}
			}
			
			for ( i=0; i<MAXENE_CONCHA; i++ ) {
				if ( ( concha[i]->comprobarDisparo() ) && (concha[i]->getActivo() == 1) ) {
					disp_ene->crearDisparo( concha[i]->getTipo_Disparo(), concha[i]->getMov_Disparo(), concha[i]->getCentroX(), concha[i]->getCentroY(), 0, 0);
				}
			}
			
			for ( i=0; i<MAXENE_TANQUE; i++ ) {
				if ( ( tanque[i]->comprobarDisparo() ) && (tanque[i]->getActivo() == 1) ) {
					x = tanque[i]->getCentroX() + (int)(disp_ene->getCoseno(tanque[i]->getPosTorreta()*2)*55);
					y = tanque[i]->getCentroY() - (int)(disp_ene->getSeno(tanque[i]->getPosTorreta()*2)*55);
					disp_ene->crearDisparo( tanque[i]->getTipo_Disparo(), tanque[i]->getMov_Disparo(), x, y, 0, tanque[i]->getPosTorreta());
				}
			}
			
		} // FINAL DISPAROS FASE 2
		
		for ( i=0; i<MAXENE_GEN2; i++ ) {
			if ( ( navemed[i]->comprobarDisparo() ) && (navemed[i]->getActivo() == 1) ) {
				disp_ene->crearDisparo( navemed[i]->getTipo_Disparo(), navemed[i]->getMov_Disparo(), navemed[i]->getCentroX(), navemed[i]->getCentroY(), 0, 0);
			}
			if ( ( gavibot[i]->comprobarDisparo() ) && (gavibot[i]->getActivo() == 1) ) {
				disp_ene->crearDisparo( gavibot[i]->getTipo_Disparo(), gavibot[i]->getMov_Disparo(), gavibot[i]->getCentroX(), gavibot[i]->getCentroY(), 0, 0);
			}
			if ( ( avispa[i]->comprobarDisparo() ) && (avispa[i]->getActivo() == 1) ) {
				disp_ene->crearDisparo( avispa[i]->getTipo_Disparo(), avispa[i]->getMov_Disparo(), avispa[i]->getCentroX(), avispa[i]->getCentroY(), 0, 0);
			}
		}
	
		for ( i=0; i<MAXENE_GEN3; i++ ) {
			if ( ( navezepelin[i]->comprobarDisparo() ) && (navezepelin[i]->getActivo() == 1) ) {
				disp_ene->crearDisparo( navezepelin[i]->getTipo_Disparo(), navezepelin[i]->getMov_Disparo(), navezepelin[i]->getCentroX(), navezepelin[i]->getCentroY(), 0, 0);
			}
			if ( ( navegrande[i]->comprobarDisparo() ) && (navegrande[i]->getActivo() == 1) ) {
				disp_ene->crearDisparo( navegrande[i]->getTipo_Disparo(), navegrande[i]->getMov_Disparo(), navegrande[i]->getCentroX(), navegrande[i]->getCentroY(), 0, 0);
			}
			if ( ( naverascasio[i]->comprobarDisparo() ) && (naverascasio[i]->getActivo() == 1) ) {
				disp_ene->crearDisparo( naverascasio[i]->getTipo_Disparo(), naverascasio[i]->getMov_Disparo(), naverascasio[i]->getCentroX(), naverascasio[i]->getCentroY(), 0, 0);
			}
		}
	}
}


int Pantalla::elementoLibre (int ele) {
	int i;
	switch (ele) {
		case GAVIOTA1:
			for (i=0; i < MAXENE_GEN1; i++) {
				if (gaviotas[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case GAVIOTA2:
			for (i=0; i < MAXENE_GEN1; i++) {
				if (gaviotas2[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case NAVEPEQUENYA:
			for (i=0; i < MAXENE_GEN1; i++) {
				if (navepeq[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case NAVEGRANDE:
			for (i=0; i < MAXENE_GEN3; i++) {
				if (navegrande[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case NAVEZEPELIN:
			for (i=0; i < MAXENE_GEN3; i++) {
				if (navezepelin[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case NAVERASCASIO:
			for (i=0; i < MAXENE_GEN3; i++) {
				if (naverascasio[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case NAVEMEDIANA:
			for (i=0; i < MAXENE_GEN2; i++) {
				if (navemed[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case GAVIBOTS:
			for (i=0; i < MAXENE_GEN2; i++) {
				if (gavibot[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case AVISPA:
			for (i=0; i < MAXENE_GEN2; i++) {
				if (avispa[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case AGREGADOR:
			for (i=0; i < MAXAGREGADORES; i++) {
				if (agregadores[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case CANGREBOT:
			for (i=0; i < MAXENE_MARINOS; i++) {
				if (cangrejo[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case LANCHA:
			for (i=0; i < MAXENE_AUTOMARINO; i++) {
				if (lancha[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case CASETA:
			for (i=0; i < MAXENE_CONSTRUCCIONES; i++) {
				if (caseta[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case MINA:
			for (i=0; i < MAXENE_MINA; i++) {
				if (mina[i]->getActivo() == 0) {
					sonido->playSonido(SND_SILBIDO);
					return i;
				}
			}			
		break;
		case COCHE_POLICIA:
			for (i=0; i < MAXENE_CPOLICIA; i++) {
				if (cpolicia[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case TANQUE:
			for (i=0; i < MAXENE_TANQUE; i++) {
				if (tanque[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case TAXI:
			for (i=0; i < MAXENE_TAXI; i++) {
				if (taxi[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case COCHESIMPLE:
			for (i=0; i < MAXENE_CSIMPLE; i++) {
				if (csimple[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case BARRERA_IZQ:
			for (i=0; i < MAXENE_BARRERAS; i++) {
				if (barrera_izq[i]->getActivo() == 0) {
					return i;
				}
			}
		break;
		case BARRERA_DER:
			for (i=0; i < MAXENE_BARRERAS; i++) {
				if (barrera_der[i]->getActivo() == 0) {
					return i;
				}
			}
		break;
		case VALLA_IZQ:
			for (i=0; i < MAXENE_BARRERAS; i++) {
				if (valla_izq[i]->getActivo() == 0) {
					return i;
				}
			}
		break;
		case VALLA_DER:
			for (i=0; i < MAXENE_BARRERAS; i++) {
				if (valla_der[i]->getActivo() == 0) {
					return i;
				}
			}
		break;
		case CARROZA:
			for (i=0; i < MAXENE_CARROZAS; i++) {
				if (carroza[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case HELICOPTERO:
			for (i=0; i < MAXENE_GEN1; i++) {
				if (helicoptero[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case CHISPA:
			for (i=0; i < MAX_CHISPAS; i++) {
				if (chispas[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case PULPO:
			for (i=0; i < MAXENE_MARINOS; i++) {
				if (pulpo[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case YATE:
			for (i=0; i < MAXENE_YATE; i++) {
				if (yate[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
		case CONCHA:
			for (i=0; i < MAXENE_CONCHA; i++) {
				if (concha[i]->getActivo() == 0) {
					return i;
				}
			}			
		break;
	}
	return	-1;
}


void Pantalla::crearFormacionEnFila(GeneralNivel1 *est, int numEnemigos, int cic, int ele, int addX, int addY) {
	int numLibre, i;
	for ( i=0; i < numEnemigos; i++ ) {
		switch (ele) {
		case GAVIOTA1:
			numLibre = elementoLibre (GAVIOTA1);
			if (numLibre != -1) {
				gaviotas[numLibre]->duplicarEnFila(est, cic*(i+1), addX*(i+1), addY*(i+1));
			}
		break;
		case GAVIOTA2:
			numLibre = elementoLibre (GAVIOTA2);
			if (numLibre != -1) {
				gaviotas2[numLibre]->duplicarEnFila(est, cic*(i+1), addX*(i+1), addY*(i+1));
			}
		break;
		case NAVEPEQUENYA:
			numLibre = elementoLibre (NAVEPEQUENYA);
			if (numLibre != -1) {
				navepeq[numLibre]->duplicarEnFila(est, cic*(i+1), addX*(i+1), addY*(i+1));
			}
		break;
		}
	}
}

void Pantalla::crearElemento () {
	switch(juego->getNivel()) {
		case 0:
			crearElementoComoJugar();
		break;
		case 1:
			crearElementoNivel1();
		break;
		case 2:
			crearElementoNivel2();
		break;
		case 3:
			crearElementoNivel3();
		break;
	}
}


void Pantalla::moverEnemigoTierra () {
	int i;
	
	//******************************************
	// MOVER ENEMIGOS DE LA FASE 1
	//******************************************
	
	if (juego->getNivel() ==1) {

		// mover cangrebot
		for (i=0; i < MAXENE_MARINOS; i++) {
			if (cangrejo[i]->getActivo() == 1) {
				cangrejo[i]->mover();
				cangrejo[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( cangrejo[i]->fueraLimitesDePantalla() ) {
					cangrejo[i]->iniciar();
				}
			}
		}
	
		// mover lancha
		for (i=0; i < MAXENE_AUTOMARINO; i++) {
			if (lancha[i]->getActivo() == 1) {
				lancha[i]->mover(jugador->getX() + (jugador->getAncho()/2));
				lancha[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( lancha[i]->fueraLimitesDePantalla() ) {
					lancha[i]->iniciar();
				}
			}
		}
		
		// mover caseta
		for (i=0; i < MAXENE_CONSTRUCCIONES; i++) {
			if (caseta[i]->getActivo() == 1) {
				caseta[i]->mover();
				caseta[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( caseta[i]->fueraLimitesDePantalla() ) {
					caseta[i]->iniciar();
				}
			}
		}
	
	} // FINALIZADO MOVIMIENTOS DE FASE 1

	//******************************************
	// MOVER ENEMIGOS DE LA FASE 3
	//******************************************
	
	if (juego->getNivel() ==3) {
		// mover coche de policia
		for (i=0; i < MAXENE_CPOLICIA; i++) {
			if (cpolicia[i]->getActivo() == 1) {
				cpolicia[i]->mover(jugador->getX() + (jugador->getAncho()/2));
				cpolicia[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( cpolicia[i]->fueraLimitesDePantalla() ) {
					cpolicia[i]->iniciar();
				}
			}
		}
		
		// mover tanque
		for (i=0; i < MAXENE_TANQUE; i++) {
			if (tanque[i]->getActivo() == 1) {
				tanque[i]->mover(jugador->getX() + (jugador->getAncho()/2));
				tanque[i]->dibujar(screen, jugador);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( tanque[i]->fueraLimitesDePantalla() ) {
					tanque[i]->iniciar();
				}
			}
		}
		
		// mover taxi
		for (i=0; i < MAXENE_TAXI; i++) {
			if (taxi[i]->getActivo() == 1) {
				taxi[i]->mover(jugador->getX() + (jugador->getAncho()/2));
				taxi[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( taxi[i]->fueraLimitesDePantalla() ) {
					taxi[i]->iniciar();
				}
			}
		}
		
		// mover coches simples
		for (i=0; i < MAXENE_CSIMPLE; i++) {
			if (csimple[i]->getActivo() == 1) {
				csimple[i]->mover(jugador->getX() + (jugador->getAncho()/2));
				csimple[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( csimple[i]->fueraLimitesDePantalla() ) {
					csimple[i]->iniciar();
				}
			}
		}
		
		// mover carrozas
		for (i=0; i < MAXENE_CARROZAS; i++) {
			if (carroza[i]->getActivo() == 1) {
				carroza[i]->mover(jugador->getX() + (jugador->getAncho()/2));
				carroza[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( carroza[i]->fueraLimitesDePantalla() ) {
					carroza[i]->iniciar();
				}
			}
		}
		
		
		// mover barreras
		for (i=0; i < MAXENE_BARRERAS; i++) {
			if (valla_izq[i]->getActivo() == 1) {
				valla_izq[i]->mover();
				valla_izq[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( valla_izq[i]->fueraLimitesDePantalla() ) {
					valla_izq[i]->iniciar();
				}
			}
			if (valla_der[i]->getActivo() == 1) {
				valla_der[i]->mover();
				valla_der[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( valla_der[i]->fueraLimitesDePantalla() ) {
					valla_der[i]->iniciar();
				}
			}
			if (barrera_izq[i]->getActivo() == 1) {
				barrera_izq[i]->mover();
				barrera_izq[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( barrera_izq[i]->fueraLimitesDePantalla() ) {
					barrera_izq[i]->iniciar();
				}
			}
			if (barrera_der[i]->getActivo() == 1) {
				barrera_der[i]->mover();
				barrera_der[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( barrera_der[i]->fueraLimitesDePantalla() ) {
					barrera_der[i]->iniciar();
				}
			}
		}

	} // FINALIZADO MOVIMIENTOS DE FASE 3

	//******************************************
	// MOVER ENEMIGOS DE LA FASE 2
	//******************************************
	
	if (juego->getNivel() ==2) {

		// dibujar rampa elcano
		if (cano->getActivo() == 1) {
			cano->dibujarRampa(screen);
		}
		
		// mover cangrebot
		for (i=0; i < MAXENE_MARINOS; i++) {
			if (cangrejo[i]->getActivo() == 1) {
				cangrejo[i]->mover();
				cangrejo[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( cangrejo[i]->fueraLimitesDePantalla() ) {
					cangrejo[i]->iniciar();
				}
			}
			if (pulpo[i]->getActivo() == 1) {
				pulpo[i]->mover();
				pulpo[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( pulpo[i]->fueraLimitesDePantalla() ) {
					pulpo[i]->iniciar();
				}
			}
		}
	
		// mover lancha
		for (i=0; i < MAXENE_AUTOMARINO; i++) {
			if (lancha[i]->getActivo() == 1) {
				lancha[i]->mover(jugador->getX() + (jugador->getAncho()/2));
				lancha[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( lancha[i]->fueraLimitesDePantalla() ) {
					lancha[i]->iniciar();
				}
			}
		}
		
		// mover yate
		for (i=0; i < MAXENE_YATE; i++) {
			if (yate[i]->getActivo() == 1) {
				yate[i]->mover(jugador->getX() + (jugador->getAncho()/2));
				yate[i]->dibujar(screen, jugador);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( yate[i]->fueraLimitesDePantalla() ) {
					yate[i]->iniciar();
				}
			}
		}
		
		// mover coche de policia
		for (i=0; i < MAXENE_CPOLICIA; i++) {
			if (cpolicia[i]->getActivo() == 1) {
				cpolicia[i]->mover(jugador->getX() + (jugador->getAncho()/2));
				cpolicia[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( cpolicia[i]->fueraLimitesDePantalla() ) {
					cpolicia[i]->iniciar();
				}
			}
		}
		
		// mover concha
		for (i=0; i < MAXENE_CONCHA; i++) {
			if (concha[i]->getActivo() == 1) {
				concha[i]->mover();
				concha[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( concha[i]->fueraLimitesDePantalla() ) {
					concha[i]->iniciar();
				}
			}
		}
		
		// mover tanque
		for (i=0; i < MAXENE_TANQUE; i++) {
			if (tanque[i]->getActivo() == 1) {
				tanque[i]->mover(jugador->getX() + (jugador->getAncho()/2));
				tanque[i]->dibujar(screen, jugador);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( tanque[i]->fueraLimitesDePantalla() ) {
					tanque[i]->iniciar();
				}
			}
		}
		
		// mover taxi
		for (i=0; i < MAXENE_TAXI; i++) {
			if (taxi[i]->getActivo() == 1) {
				taxi[i]->mover(jugador->getX() + (jugador->getAncho()/2));
				taxi[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( taxi[i]->fueraLimitesDePantalla() ) {
					taxi[i]->iniciar();
				}
			}
		}
		
		// mover coches simples
		for (i=0; i < MAXENE_CSIMPLE; i++) {
			if (csimple[i]->getActivo() == 1) {
				csimple[i]->mover(jugador->getX() + (jugador->getAncho()/2));
				csimple[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( csimple[i]->fueraLimitesDePantalla() ) {
					csimple[i]->iniciar();
				}
			}
		}
		
		// mover barreras
		for (i=0; i < MAXENE_BARRERAS; i++) {
			if (valla_izq[i]->getActivo() == 1) {
				valla_izq[i]->mover();
				valla_izq[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( valla_izq[i]->fueraLimitesDePantalla() ) {
					valla_izq[i]->iniciar();
				}
			}
			if (valla_der[i]->getActivo() == 1) {
				valla_der[i]->mover();
				valla_der[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( valla_der[i]->fueraLimitesDePantalla() ) {
					valla_der[i]->iniciar();
				}
			}
			if (barrera_izq[i]->getActivo() == 1) {
				barrera_izq[i]->mover();
				barrera_izq[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( barrera_izq[i]->fueraLimitesDePantalla() ) {
					barrera_izq[i]->iniciar();
				}
			}
			if (barrera_der[i]->getActivo() == 1) {
				barrera_der[i]->mover();
				barrera_der[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( barrera_der[i]->fueraLimitesDePantalla() ) {
					barrera_der[i]->iniciar();
				}
			}
		}
		
		// mover elcano
		if (cano->getActivo() == 1) {
			cano->mover();
			cano->dibujar(screen);
			// comprobar si el enemigo ha salido de la pantalla para eliminarlo
			if ( cano->getY()>screen_h ) {
				cano->iniciar();
			}
		}
		
	} // FINALIZADO MOVIMIENTOS DE FASE 2

	
}

void Pantalla::moverEnemigoAire () {
	int i;
	
	//******************************************
	// MOVER ENEMIGOS DE LA FASE 1
	//******************************************
	
	if (juego->getNivel() ==1) {
		// mover minas
		for (i=0; i < MAXENE_MINA; i++) {
			if (mina[i]->getActivo() == 1) {
				mina[i]->mover();
				mina[i]->dibujar(screen);
				// comprobar si el enemigo ha salido de la pantalla para eliminarlo
				if ( mina[i]->fueraLimitesDePantalla() ) {
					mina[i]->iniciar();
				}
			}
		}
		
	} // FINALIZADO MOVIMIENTOS DE FASE 1

	
	//******************************************
	// MOVER ENEMIGOS COMUNES
	//******************************************
	
	// mover gaviotas
	for (i=0; i < MAXENE_GEN1; i++) {
		if (gaviotas[i]->getActivo() == 1) {
			gaviotas[i]->mover(jugador->getX() + (jugador->getAncho()/2));
			gaviotas[i]->dibujar(screen);
			// comprobar si el enemigo ha salido de la pantalla para eliminarlo
			if ( gaviotas[i]->fueraLimitesDePantalla() ) {
				gaviotas[i]->iniciar();
			}
		}
	}

	// mover gaviotas2
	for (i=0; i < MAXENE_GEN1; i++) {
		if (gaviotas2[i]->getActivo() == 1) {
			gaviotas2[i]->mover(jugador->getX() + (jugador->getAncho()/2));
			gaviotas2[i]->dibujar(screen);
			// comprobar si el enemigo ha salido de la pantalla para eliminarlo
			if ( gaviotas2[i]->fueraLimitesDePantalla() ) {
				gaviotas2[i]->iniciar();
			}
		}
	}
	
	// mover nave pequeña
	for (i=0; i < MAXENE_GEN1; i++) {
		if (navepeq[i]->getActivo() == 1) {
			navepeq[i]->mover(jugador->getX() + (jugador->getAncho()/2));
			navepeq[i]->dibujar(screen);
			// comprobar si el enemigo ha salido de la pantalla para eliminarlo
			if ( navepeq[i]->fueraLimitesDePantalla() ) {
				navepeq[i]->iniciar();
			}
		}
	}
	
	// mover helicoptero
	for (i=0; i < MAXENE_GEN1; i++) {
		if (helicoptero[i]->getActivo() == 1) {
			helicoptero[i]->mover(jugador->getX() + (jugador->getAncho()/2));
			helicoptero[i]->dibujar(screen);
			// comprobar si el enemigo ha salido de la pantalla para eliminarlo
			if ( helicoptero[i]->fueraLimitesDePantalla() ) {
				helicoptero[i]->iniciar();
			}
		}
	}
	
	// mover nave mediana
	for (i=0; i < MAXENE_GEN2; i++) {
		if (navemed[i]->getActivo() == 1) {
			navemed[i]->mover(jugador->getX() + (jugador->getAncho()/2));
			navemed[i]->dibujar(screen);
			// comprobar si el enemigo ha salido de la pantalla para eliminarlo
			if ( navemed[i]->fueraLimitesDePantalla() ) {
				navemed[i]->iniciar();
			}
		}
	}
	
	// mover gavibot
	for (i=0; i < MAXENE_GEN2; i++) {
		if (gavibot[i]->getActivo() == 1) {
			gavibot[i]->mover(jugador->getX() + (jugador->getAncho()/2));
			gavibot[i]->dibujar(screen);
			// comprobar si el enemigo ha salido de la pantalla para eliminarlo
			if ( gavibot[i]->fueraLimitesDePantalla() ) {
				gavibot[i]->iniciar();
			}
		}
	}
	
	// mover avispa
	for (i=0; i < MAXENE_GEN2; i++) {
		if (avispa[i]->getActivo() == 1) {
			avispa[i]->mover(jugador->getX() + (jugador->getAncho()/2));
			avispa[i]->dibujar(screen);
			// comprobar si el enemigo ha salido de la pantalla para eliminarlo
			if ( avispa[i]->fueraLimitesDePantalla() ) {
				avispa[i]->iniciar();
			}
		}
	}
	
	// mover nave grande
	for (i=0; i < MAXENE_GEN3; i++) {
		if (navegrande[i]->getActivo() == 1) {
			navegrande[i]->mover(jugador->getX() + (jugador->getAncho()/2));
			navegrande[i]->dibujar(screen);
			// comprobar si el enemigo ha salido de la pantalla para eliminarlo
			if ( navegrande[i]->fueraLimitesDePantalla() ) {
				navegrande[i]->iniciar();
			}
		}
	}
	
	// mover nave zepelin
	for (i=0; i < MAXENE_GEN3; i++) {
		if (navezepelin[i]->getActivo() == 1) {
			navezepelin[i]->mover(jugador->getX() + (jugador->getAncho()/2));
			navezepelin[i]->dibujar(screen);
			// comprobar si el enemigo ha salido de la pantalla para eliminarlo
			if ( navezepelin[i]->fueraLimitesDePantalla() ) {
				navezepelin[i]->iniciar();
			}
		}
	}
	
	// mover nave rascasio
	for (i=0; i < MAXENE_GEN3; i++) {
		if (naverascasio[i]->getActivo() == 1) {
			naverascasio[i]->mover(jugador->getX() + (jugador->getAncho()/2));
			naverascasio[i]->dibujar(screen);
			// comprobar si el enemigo ha salido de la pantalla para eliminarlo
			if ( naverascasio[i]->fueraLimitesDePantalla() ) {
				naverascasio[i]->iniciar();
			}
		}
	}

	
}

void Pantalla::unLoad() {
	// descargar sprites
	jugador->unLoad();
	gaviotas[0]->unLoad();
	gaviotas2[0]->unLoad();
	navepeq[0]->unLoad();
	navemed[0]->unLoad();
	gavibot[0]->unLoad();
	avispa[0]->unLoad();
	navegrande[0]->unLoad();
	navezepelin[0]->unLoad();
	naverascasio[0]->unLoad();
	agregadores[0]->unLoad();
	/*
	// descargar disparos de enemigos
	disp_ene->unLoad();	
	// descargar barra
	barra->unLoad();	
	// descargar explosiones
	explosiones->unLoad();
	*/
	// descargar fuentes
	fuente->unLoadFuente();	
	// descargar sonido
	sonido->unLoadSonido();	
	// descargar joystick
	joystick->unLoadJoystick();
	
	//otros
	banda_Nivel->unLoad();
	negro->unLoad();

}

void Pantalla::iniciarPantalla() {
	
	enFinal = false;
	enVSFinal = false;
	
	salir = 0;
	pulsadoSelPoder = 0;
	//disparosContinuos = 0;
	//esperaDisparosContinuos = 0;
	final = 0;
	auxEstadoSalirPartida = -1;
	volverAOpciones = false;
	joyx = 0;
	joyy = 0;
	
	// descargar sprites
	int i;


	//******************************************
	// INICIAR ENEMIGOS DE LA FASE 1
	//******************************************
	if (juego->getNivel()==1) {
		for (i=0; i<MAXENE_MARINOS; i++) {
			cangrejo[i]->iniciar();
		}
		
		for (i=0; i < MAXENE_AUTOMARINO; i++) {
			lancha[i]->iniciar();
		}
		for (i=0; i < MAXENE_CONSTRUCCIONES; i++) {
			caseta[i]->iniciar();
		}	
		for (i=0; i < MAXENE_MINA; i++) {
			mina[i]->iniciar();
		}
		
		for (i=0; i < MAXENE_YATE; i++) {
			yate[i]->iniciar();
		}
		
		torrebal_der->iniciar();
		torrebal_izq->iniciar();
		jefe1->iniciar();
	} // FINAL DE INCICIAR ENEMIGOS DE LA FASE 1
	
	//******************************************
	// INICIAR ENEMIGOS DE LA FASE 3
	//******************************************
	if (juego->getNivel()==3) {
		for (i=0; i<MAXENE_CPOLICIA; i++) {
			cpolicia[i]->iniciar();
		}
		for (i=0; i<MAXENE_TANQUE; i++) {
			tanque[i]->iniciar();
		}
		for (i=0; i<MAXENE_CSIMPLE; i++) {
			csimple[i]->iniciar();
		}
		for (i=0; i<MAXENE_TAXI; i++) {
			taxi[i]->iniciar();
		}
		for (i=0; i < MAXENE_BARRERAS; i++) {
			valla_izq[i]->iniciar();
			valla_der[i]->iniciar();
			barrera_der[i]->iniciar();
			barrera_izq[i]->iniciar();
		}
		for (i=0; i < MAXENE_CARROZAS; i++) {
			carroza[i]->iniciar();
		}
		for (i=0; i < 3; i++) {
			jefe3[i]->setActivo(0);
		}
	} // FINAL DE INCICIAR ENEMIGOS DE LA FASE 3
	
	//******************************************
	// INICIAR ENEMIGOS DE LA FASE 2
	//******************************************
	if (juego->getNivel()==2) {
		for (i=0; i<MAXENE_MARINOS; i++) {
			cangrejo[i]->iniciar();
			pulpo[i]->iniciar();
		}
		
		for (i=0; i < MAXENE_AUTOMARINO; i++) {
			lancha[i]->iniciar();
		}
		
		for (i=0; i < MAXENE_YATE; i++) {
			yate[i]->iniciar();
		}
		
		for (i=0; i<MAXENE_CPOLICIA; i++) {
			cpolicia[i]->iniciar();
		}
		for (i=0; i<MAXENE_TANQUE; i++) {
			tanque[i]->iniciar();
		}
		for (i=0; i<MAXENE_CSIMPLE; i++) {
			csimple[i]->iniciar();
		}
		for (i=0; i<MAXENE_TAXI; i++) {
			taxi[i]->iniciar();
		}
		for (i=0; i < MAXENE_BARRERAS; i++) {
			valla_izq[i]->iniciar();
			valla_der[i]->iniciar();
			barrera_der[i]->iniciar();
			barrera_izq[i]->iniciar();
		}
		for (i=0; i<MAXENE_CONCHA; i++) {
			concha[i]->iniciar();
		}
		
		cano->iniciar();
		
	}
	
	for (i=0; i <MAXENE_GEN1; i++) {
		gaviotas[i]->iniciar();
		gaviotas2[i]->iniciar();
		navepeq[i]->iniciar();
		helicoptero[i]->iniciar();
	}

	for (i=0; i <MAXENE_GEN2; i++) {
		navemed[i]->iniciar();
		gavibot[i]->iniciar();
		avispa[i]->iniciar();
	}
		
	for (i=0; i < MAXENE_GEN3; i++) {
		navegrande[i]->iniciar();
		navezepelin[i]->iniciar();
		naverascasio[i]->iniciar();
	}

	for (i=0; i<MAXAGREGADORES; i++) {
		agregadores[i]->iniciar();
	}
	disp_ene->iniciar();
	jugador->getDisparoJugador()->iniciar();
	
	final = 0;
	
	tiempoBloqueoDisparosEnemigos = 0;
	
	// iniciamos tiempo

	tiempo->iniciar();
	
	// cerrar todos los personajes
	// ponemos el frame 0 en todos
	intercom->cerrarIntercom(sonido);
	barra->persPaco->selFrame(0);
	
	// esto vale para llegar el mapa a un ciclos en concreto
	int suma = 0;
	int c = suma * 260;
	//c = 4700;
	
	setCiclos(c);	
	mapa->iniciar(suma);
	
	explosiones->iniciar();
	
	//empezarMusica(1);
	ciclosNivel = 100;
	txtFase->setX(screen_w+250);
	txtFase->setPorPosicionX(screen_w/2);
	txtNivel->setX(-txtNivel->getAncho()-250);
	txtNivel->setPorPosicionX(screen_w/2);
	//juego->iniciar();

	juego->setHacerClip(1);

	intercom->setIntercomAbierto(0);

	setFinal(0);
	juego->setEnFinal(false);
	setSalirFase(0);

	juego->setCicloConversarionAleatoria ();
	
	juego->setConversacionParaAbrirEnFase();
	
	
	entradaJugador ();
	
	EnPoderCadista = false;
	
	juego->setMapaParado(false);
	
}

void Pantalla::empezarFaseEnTrozo(int trozo) {
	int c = trozo * 260;
	setCiclos(c);
	mapa->iniciar(trozo);
}


void Pantalla::iniciarJuego() {
	juego->setPuntos(0);
	juego->setVidas(2);
	juego->setPoderes(2);
	juego->setBarraPoder(0);
	juego->setPoderSel(1);
}

void Pantalla::empezarMusica(int l) {
	switch(l) {
		case 0:
		case 1:
			sonido->empezarMusica(MUS_FASE1);
		break;
		case 2:
			sonido->empezarMusica(MUS_FASE2);
		break;
		case 3:
			sonido->empezarMusica(MUS_FASE3);
		break;
	}
}

void Pantalla::empezarMusicaFase() {
	empezarMusica(juego->getNivel());
}

void Pantalla::empezarMusicaFinal() {
	switch(juego->getNivel()) {
		case 1:
			sonido->empezarMusica(MUS_FINAL1);
		break;
		case 2:
			sonido->empezarMusica(MUS_FINAL2);
		break;
		case 3:
			sonido->empezarMusica(MUS_FINAL3);
		break;
	}
}

void Pantalla::dibujarImg() {
	char tmpdir[120];
	sprintf(tmpdir, "%s/img.bmp", config->getDirectorio());
	SDL_BlitSurface (SDL_LoadBMP(tmpdir), NULL, screen, NULL);
}


void Pantalla::ejecutar() {
	
	int tmp;
	char tmpch[127];
	char nombreRecord[50]="";
	char tmpNombreRecord[1] ="";
	int tamNombreRecord=0;
	bool SiNo = 0;
	int hacerFlipOpciones = 0; // esta variable refresca en el primer frame de la pantalla 
												// de opciones si está a 1
	
	SDL_Event event;
	SDL_Rect clip_completo;
	clip_completo.x = 0;
	clip_completo.y = 0;
	clip_completo.h = 480;
	clip_completo.w = 640;
	SDL_Rect clip_barra;
	clip_barra.x = 552;
	clip_barra.y = 176;
	clip_barra.h = 80;
	clip_barra.w = 90;
	
	int r;
	
	estado = 1;
	int estadoAntesPausa = 0;
	int done = 0;
	
	nextTime();
	while (done == 0) {
		switch (estado) {
			// *********************
			// Estado de Pausa
			// *********************
			case JUEGO_PAUSA:
			// Comprobando teclas para opciones
				while (SDL_PollEvent(&event)) {
					// Cerrar la ventana
					if (event.type == SDL_QUIT) { done = 1; } 
					// Pulsando una tecla
					if ( (event.type == SDL_KEYDOWN) || (event.type == SDL_JOYBUTTONDOWN) ) {
						// Pulsar ESCAPE se sale
						if (event.key.keysym.sym == SDLK_ESCAPE) { 
							estado = estadoAntesPausa; 
						}
						// Pulsar P para pausa
						if (event.key.keysym.sym == SDLK_p) { 
							estado = estadoAntesPausa;
						}
						/*
						if ( (event.key.keysym.sym == SDLK_LSHIFT) ||
							(event.key.keysym.sym == SDLK_RSHIFT) ||
							(event.key.keysym.sym == SDLK_1) ||
							(event.key.keysym.sym == SDLK_2) ||
							(event.key.keysym.sym == SDLK_3) ||
							(event.key.keysym.sym == SDLK_4) ) { 
							pantalla->getJugador()->comprobarTeclas(false, false, true);
							SDL_SetClipRect (pantalla->screen, &clip_barra);
							pantalla->dibujarBarra();
							SDL_Flip (pantalla->screen);
							pantalla->pulsadoSelPoder = 0;
						}*/
					}
				}
			break;
			// *********************
			// Estado de SEL PODER
			// *********************
			case JUEGO_SEL_PODER:
			// Comprobando teclas para opciones
				while (SDL_PollEvent(&event)) {
					// Cerrar la ventana
					if (event.type == SDL_QUIT) { done = 1; } 
					// Pulsando una tecla
					if ( (event.type == SDL_KEYDOWN) || (event.type == SDL_JOYAXISMOTION)
							|| (event.type == SDL_JOYBUTTONDOWN) ) {
						// salimos
						if ( (event.key.keysym.sym == SDLK_ESCAPE) ||
							(event.key.keysym.sym == SDLK_RETURN) ||
							(event.key.keysym.sym == SDLK_LSHIFT) ||
							(event.key.keysym.sym == SDLK_RSHIFT) ||
							(joystick->comprobarBotonJoystick(JOY_SEL_PODER)) ) { 
							switch (juego->getPoderSel()) {
								case 1:
									sonido->playSonido(SND_ACTIVAR_ESCUDO);	
								break;
								case 2:
									if (rand()%2==0)
										sonido->playSonido(SND_ACTIVAR_BOMBA0);	
									else
										sonido->playSonido(SND_ACTIVAR_BOMBA1);	
								break;
								case 3:
									sonido->playSonido(SND_ACTIVAR_CLONACION);	
								break;
								case 4:
									sonido->playSonido(SND_ACTIVAR_AMARILLO);	
								break;
							}
							estado = estadoAntesPausa; 
						}
						if ( ( event.key.keysym.sym == SDLK_RIGHT ) 
							|| (event.jaxis.value > 3200 && event.jaxis.axis == 0 && event.type == SDL_JOYAXISMOTION ) ) { 
							sonido->playSonido(SND_BEEP1);
							getJuego()->addPoderSel();
							//SDL_SetClipRect (pantalla->screen, &clip_barra);
							//pantalla->dibujarBarra();
							EscenaEnSel_Poder();
							//pantalla->pulsadoSelPoder = 0;
						}
						if ( ( event.key.keysym.sym == SDLK_LEFT ) 
							|| ( event.jaxis.value < -3200 && event.jaxis.axis == 0 && event.type == SDL_JOYAXISMOTION ) )	
						{ 
							sonido->playSonido(SND_BEEP1);
							getJuego()->removePoderSel();
							//SDL_SetClipRect (pantalla->screen, &clip_barra);
							//pantalla->dibujarBarra();
							EscenaEnSel_Poder();
							//pantalla->pulsadoSelPoder = 0;
						}
					}
				}
			break;
			// *********************
			// Estado de portada
			// *********************
			case JUEGO_PORTADA:
				r = introPortada->DrawAnimation();
				SDL_Flip (screen);
				if (r==1) {
					initElementosComunes();
					estado = JUEGO_OPCIONES;
					hacerFlipOpciones = 1;
					sonido->empezarMusica(MUS_OPCIONES);
				}
				/*SDL_SetClipRect (screen, &clip_completo);
				portada->dibujar(screen);
				SDL_Flip (screen);
				// Comprobando teclas para opciones
				while (SDL_PollEvent(&event)) {
					// Cerrar la ventana
					if (event.type == SDL_QUIT) { done = 1; } 
					// Pulsando una tecla
					if ( (event.type == SDL_KEYDOWN) || (event.type == SDL_JOYBUTTONDOWN) ) {
						// Pulsar ESCAPE se sale
						if (event.key.keysym.sym == SDLK_ESCAPE) { 
							done = 1; 
						} else {
							estado = JUEGO_OPCIONES;
							hacerFlipOpciones = 1;
							sonido->empezarMusica(MUS_OPCIONES);
						}
					}
				}*/
			break;
			// *********************
			// Estado de como jugar
			// *********************
			case JUEGO_COMOJUGAR:
				EscenaEnComoJugar();
				// Comprobando teclas para opciones
				while (SDL_PollEvent(&event)) {
					// Cerrar la ventana
					if (event.type == SDL_QUIT) { done = 1; } 
					// Pulsando una tecla
					if ( (event.type == SDL_KEYDOWN) || (event.type == SDL_JOYBUTTONDOWN) ) {
						// Pulsar ESCAPE se sale
						if (event.key.keysym.sym == SDLK_ESCAPE) { 
							estado = JUEGO_OPCIONES; 
							hacerFlipOpciones = 1;
							Mix_HaltChannel(-1);
							sonido->empezarMusica(MUS_OPCIONES);
							auxEstadoSalirPartida = -1;
						}
					}
					
				}
			break;
			// *********************
			// Estado de juego
			// *********************
			case JUEGO_ESCENA:
				Escena();
				if (getVidas() < 0) {
					setHacerClip(1);
					estado = JUEGO_OVER;
					Mix_HaltChannel(-1);
				}
				if (getVolverAOpciones()) {
					estado = JUEGO_OPCIONES; 
					hacerFlipOpciones = 1;
					Mix_HaltChannel(-1);
					sonido->empezarMusica(MUS_OPCIONES);
					auxEstadoSalirPartida = -1;
				}
				// Comprobando teclas para opciones
				while (SDL_PollEvent(&event)) {
					// Cerrar la ventana
					if (event.type == SDL_QUIT) { done = 1; } 
					// Pulsando una tecla
					if ( (event.type == SDL_KEYDOWN) || (event.type == SDL_JOYBUTTONDOWN) ) {
						// Pulsar ESCAPE se sale
						if (event.key.keysym.sym == SDLK_ESCAPE) { 
							if (getSalirFase()>0) { // si está saliendo de fase vamos a la siguiente
								cargarSiguienteFase();
							} else { // sino salimos del juego
								guardarImg();
								estado = JUEGO_SALIRPARTIDA; 
								//Mix_HaltChannel(-1);
							}
							//pantalla->sonido->empezarMusica(MUS_OPCIONES);
						}
						// Pulsar P para pausa
						if (event.key.keysym.sym == SDLK_p) { 
							estadoAntesPausa = estado;
							estado = JUEGO_PAUSA;
							EscenaEnPausa();
						}
						// Pulsar ESPACIO para intercom
						if ( (event.key.keysym.sym == SDLK_SPACE) || (joystick->comprobarBotonJoystick(JOY_INTERCOM) ) ) { 
							if (getIntercom()->getIntercomAbierto() == 1) {
								guardarImg();
								estado = JUEGO_INTERCOM;
								getIntercom()->cargarAnimacion();
								sonido->terminarIntercom();
							}
						}
						// entrar en seleccion de poder
						if ( ( (event.key.keysym.sym == SDLK_LSHIFT) || 
							(event.key.keysym.sym == SDLK_LSHIFT) ||
							(joystick->comprobarBotonJoystick(JOY_SEL_PODER)) ) && (!juego->getPoderActivo()) ){ 
							guardarImg();
							EscenaEnSel_Poder();
							estadoAntesPausa = estado;
							estado = JUEGO_SEL_PODER;
						}
					}
				}
			break;
			// *********************
			// Estado de Intercom
			// *********************
			case JUEGO_INTERCOM:
				if (EscenaEnIntercom() == 1) {
					getIntercom()->cerrarIntercom(sonido);
					if (juego->getNivel()==0) {
						estado = JUEGO_COMOJUGAR;
					} else {
						estado = JUEGO_ESCENA;
					}					
					getJuego()->setHacerClip(0);
				}
			break;
			// *********************
			// Estado de Game Over
			// *********************
			case JUEGO_OVER:
				guardarImg();
				// comprobar si la puntuacion en mayor para poner nombre en los record
				if (getConfiguracion()->getPuntuacionMenor() < getJuego()->getPuntos()) {
					estado = JUEGO_RECORD;
				} else {
					estado = JUEGO_CONTINUE;					
				}
			break;
			// *********************
			// Estado de Record
			// *********************
			case JUEGO_RECORD:
				EscenaEnRecord(nombreRecord);
				//strcpy(tmpch, tmpchptr);
				// Comprobando teclas para opciones
				while (SDL_PollEvent(&event)) {
					// Cerrar la ventana
					if (event.type == SDL_QUIT) { done = 1; } 
					// Pulsando una tecla
					if (event.type == SDL_KEYDOWN) {
						// Pulsar ESCAPE se sale
						if (event.key.keysym.sym == SDLK_RETURN) { 
							if (strlen(nombreRecord)>0) {
								getConfiguracion()->guardarPuntuacion(nombreRecord, getJuego()->getPuntos());
								estado = JUEGO_CONTINUE;
							}
						} else if (event.key.keysym.sym == SDLK_BACKSPACE) { 
							if (tamNombreRecord>0) {
								tamNombreRecord--;
								nombreRecord[tamNombreRecord] = tmpNombreRecord[0];
							}
						} else {
							//if (opciones->teclaValida(tmpch) ) {
							if (opciones->teclaValida(event.key.keysym.sym) ) {
								strcpy(tmpch,SDL_GetKeyName(event.key.keysym.sym));
								if (strlen(nombreRecord)<15) {
									sprintf(nombreRecord, "%s%s", nombreRecord, tmpch);
									tamNombreRecord++;
								}
							}
						}
					}
				}
			break;
			// *********************
			// Estado de Salir partida
			// *********************
			case JUEGO_SALIRPARTIDA:
				EscenaEnSalirPartida(SiNo);
				// Comprobando teclas para opciones
				while (SDL_PollEvent(&event)) {
					// Cerrar la ventana
					if (event.type == SDL_QUIT) { done = 1; } 
					// Pulsando una tecla
					if ( (event.type == SDL_KEYDOWN) || (event.type == SDL_JOYAXISMOTION)
							|| (event.type == SDL_JOYBUTTONDOWN) ) {
						// Pulsar IZQUIERDA
						if ( (event.key.keysym.sym == SDLK_LEFT) || (event.key.keysym.sym == SDLK_RIGHT) 
							|| ( event.jaxis.value < -3200 && event.jaxis.axis == 0 && event.type == SDL_JOYAXISMOTION ) 
							|| (event.jaxis.value > 3200 && event.jaxis.axis == 0 && event.type == SDL_JOYAXISMOTION )) { 
							(SiNo==1) ? (SiNo =0):(SiNo=1);
						} else if ( (event.key.keysym.sym == SDLK_RETURN) ||
							(joystick->comprobarBotonJoystick(JOY_DISPARO)) ) { 
							if (SiNo==0) {
								estado = JUEGO_OPCIONES; 
								hacerFlipOpciones = 1;
								Mix_HaltChannel(-1);
								sonido->empezarMusica(MUS_OPCIONES);
								auxEstadoSalirPartida = -1;
							} else {
								//pantalla->empezarMusicaFase();
								estado = JUEGO_ESCENA; 
								auxEstadoSalirPartida = -1;
							}
						}
					}
				}
			break;
			// *********************
			// Estado de Misión Fracasada
			// *********************
			case JUEGO_MISIONFRACASADA:
				EscenaEnMensaje();
				// Comprobando teclas para opciones
				if ( SDL_WaitEvent(&event) ) {
					//while (SDL_PollEvent(&event)) {
						// Cerrar la ventana
						if (event.type == SDL_QUIT) { done = 1; } 
						// Pulsando una tecla
						if ( (event.type == SDL_KEYDOWN) || (event.type == SDL_JOYBUTTONDOWN) ) {
							//if (event.key.keysym.sym == SDLK_RETURN) { 
								estado = JUEGO_OPCIONES; 
								hacerFlipOpciones = 1;
								Mix_HaltChannel(-1);
								sonido->empezarMusica(MUS_OPCIONES);
								auxEstadoSalirPartida = -1;
							//}
						}
					//}
				}
			break;
			// *********************
			// Estado de Continue
			// *********************
			case JUEGO_CONTINUE:
				if (getJuego()->getContinue()<=0) { //fracaso total
					estado = JUEGO_MISIONFRACASADA;
				}
				EscenaEnGameOver(SiNo);
			// Comprobando teclas para opciones
				while (SDL_PollEvent(&event)) {
					// Cerrar la ventana
					if (event.type == SDL_QUIT) { done = 1; } 
					// Pulsando una tecla
					if ( (event.type == SDL_KEYDOWN) || (event.type == SDL_JOYAXISMOTION)
							|| (event.type == SDL_JOYBUTTONDOWN) ) {
						// Pulsar ESCAPE se sale
						if (event.key.keysym.sym == SDLK_ESCAPE) { 
							estado = JUEGO_OPCIONES;
							hacerFlipOpciones = 1;
							sonido->empezarMusica(MUS_OPCIONES);
						}
						// Pulsar IZQUIERDA
						if ( (event.key.keysym.sym == SDLK_LEFT) || (event.key.keysym.sym == SDLK_RIGHT) 
							|| ( event.jaxis.value < -3200 && event.jaxis.axis == 0 && event.type == SDL_JOYAXISMOTION ) 
							|| (event.jaxis.value > 3200 && event.jaxis.axis == 0 && event.type == SDL_JOYAXISMOTION )) { 
							(SiNo==1) ? (SiNo =0):(SiNo=1);
						} else if ( (event.key.keysym.sym == SDLK_RETURN) ||
							(joystick->comprobarBotonJoystick(JOY_DISPARO)) ) { 
							if (SiNo==0) { // SI
								estado = JUEGO_ESCENA; 
								auxEstadoSalirPartida = -1;
								iniciarJuego();
								iniciarPantalla();
								switch (getJuego()->getZonaSobrepasada()) {
									case 0:
										empezarMusicaFase();
									break;
									case 1:
										empezarFaseEnTrozo(8);
										empezarMusicaFase();
										entradaJugador();
									break;
									case 2:
										switch ( getJuego()->getNivel() ) {
											case 1:
												setCiclos(4780);
												initFinalNivel1();
											break;
											case 2:
												setCiclos(4550);
												initFinalNivel2();
											break;
										}
									break;
								}
								getJuego()->removeContinue();
							} else { // NO
								estado = JUEGO_OPCIONES; 
								hacerFlipOpciones = 1;
								Mix_HaltChannel(-1);
								sonido->empezarMusica(MUS_OPCIONES);
								auxEstadoSalirPartida = -1;
							}
						}
					}
				}
			break;
			// *********************
			// Estado de opciones
			// *********************
			case JUEGO_OPCIONES:
				tmp = opciones->escena();
				if (hacerFlipOpciones == 1) { hacerFlipOpciones = 0; }
				if (tmp == -1) {
					done = 1;
				} else if (tmp == 0) {
					;
				} else if (tmp > 30) {
					setVelocidadJuego(tmp);
				} else {
					estado = tmp;
				}
			break;
		}
		SDL_Delay(timeLeft());
		nextTime();
	}

}
