/*
 * Tirititran es un juego de naves en 2D ambientado en Cádiz
 * Copyright (C) 2004  Javier Pérez Pacheco
 *
 * Este juego tienen licencia Creative Commons y se permite
 * su modificacion y utilizacion libremente siempre y cuando se
 * cite al autor original y se comparta con la misma licencia.
 * No se permite su uso comercial.
 * 
 * Para mas informacion visite la web:
 * http://creativecommons.org/licenses/by-nc-sa/2.0/es/
 *
 * PROGRAMADOR
 * Javier Pérez Pacheco
 * Cadiz (Spain)
 * javi.pacheco@terra.es
 *
 * GRAFISMO Y 3D
 * Jesus Carrasco
 * Cadiz (Spain)
 * carrasco.carrasco@gmail.com
 *
 * MUSICA Y GRAFISMO
 * Shano Lores
 * Cadiz (Spain)
 * shano@mail.ono.es
 *
 */

#ifndef PANTALLA_H_
#define PANTALLA_H_

#define TRUE 1
#define FALSE 0

#include <SDL.h>
#include <SDL_mixer.h>
#include "defines.h"
#include "juego.h"
#include "disparojugador.h"
#include "disparosenemigos.h"
#include "explosion.h"
#include "barra.h"
#include "mapa.h"
#include "elementos.h"
#include "sonido.h"
#include "joystick.h"
#include "fuente.h"
#include "configuracion.h"
#include "intercom.h"
#include "tiempo.h"
#include "SDL_Animation.h"
#include "opciones.h"
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <string>
#include <vector>

using namespace std;


typedef struct
{
	bool derecha, izquierda, arriba, abajo;
	int ciclo_in;
	int ciclo_out;
} ControlMovJugadorComoJugar;

class Opciones;
	
class Pantalla {
	
private:
	int estado;	

	Configuracion *config;
	Opciones *opciones;
	SDL_Animation *intro;
	SDL_Animation *diario;
	GeneralNivel1 *gaviotas[MAXENE_GEN1];
	GeneralNivel1 *gaviotas2[MAXENE_GEN1];
	GeneralNivel1 *navepeq[MAXENE_GEN1];
	GeneralNivel2 *navemed[MAXENE_GEN2];
	GeneralNivel2 *gavibot[MAXENE_GEN2];
	GeneralNivel2 *avispa[MAXENE_GEN2];
	GeneralNivel3 *navegrande[MAXENE_GEN3];
	GeneralNivel3 *navezepelin[MAXENE_GEN3];
	GeneralNivel3 *naverascasio[MAXENE_GEN3];
	Marinos *cangrejo[MAXENE_MARINOS];
	Marinos *pulpo[MAXENE_MARINOS];
	AutoMarino *lancha[MAXENE_AUTOMARINO];
	Construcciones *caseta[MAXENE_CONSTRUCCIONES];
	Mina *mina[MAXENE_MINA];
	CochePolicia *cpolicia[MAXENE_CPOLICIA];
	Tanque *tanque[MAXENE_TANQUE];
	Yate *yate[MAXENE_YATE];
	Taxi *taxi[MAXENE_TAXI];
	Construcciones *valla_izq[MAXENE_BARRERAS];
	Construcciones *valla_der[MAXENE_BARRERAS];
	Construcciones *barrera_izq[MAXENE_BARRERAS];
	Construcciones *barrera_der[MAXENE_BARRERAS];
	CocheSimple *csimple[MAXENE_CSIMPLE];
	Carroza *carroza[MAXENE_CARROZAS];
	Helicoptero *helicoptero[MAXENE_GEN1];
	Concha *concha[MAXENE_CONCHA];
	// Instancias de explosiones
	Explosion *explosiones;
	Mapa *mapa;
	MapaAgua *mapaagua;
	Tiempo *tiempo;
	Agregador *agregadores[MAXAGREGADORES];
	DisparosEnemigos *disp_ene;
	Elemento *chispas[MAX_CHISPAS];
	
	Elemento *fondo_SelPoder;
	Elemento *poderEscudo, *poderClonacion, *poderCadista, *poderBomba;

	Juego *juego;
	int nScreenShot;
	// barra
	Barra *barra;
	// elementos del juego
	Jugador *jugador;
	vector<ControlMovJugadorComoJugar> movJugadorComoJugar;
	int cicloEstadoNaciendoFin; // ciclo en el que termina de nacer el jugador
	// otros valores
	Uint8 *keys;
	Sint16 joyx, joyy;
	int elementoLibre (int ele); // devuelve un elemento libre del array de enemigos
	int nivel;
	bool enFinal, enVSFinal;
	int final; // 0-> si está en la fase y >1 si se encuentra en el final
	int salirFase; // 0-> si no está saliendo y >1 si está saliendo de fase
	bool volverAOpciones;
	int ciclosNivel; // ciclos en los que aparece el título del nivel
	void crearFormacionEnFila	(GeneralNivel1 *est, int numEnemigos, int cic, int ele, int addX, int addY);
	SDL_Rect clip_recortado;
	Elemento *banda_Nivel; // banda donde se colocará la fase y nivel
	Elemento *negro; // elemento para colocar pantalla en negro en la pausa
	Elemento *mitadLogoArriba, *mitadLogoAbajo;
	Elemento *mitadVersusArriba, *mitadVersusAbajo;
	Elemento *rojo; // elemento para las explosiones
	Elemento *amarillo; // elemento para las balones
	Elemento *estela_bomba;
	int cicloEstela;
	int tiempoBloqueoDisparosEnemigos;
	Elemento *cargando;
	JefeFase1 *jefe1;
	TorreBalneario *torrebal_der, *torrebal_izq;
	JefeFase3 *jefe3[3];
	BioPic	*biopic;
	JefeFase2 *jefe2;
	ElCano *cano;
	Elemento *ptierra, *puente, *espumaPuente;
	BarraDeCarga *barradecarga;
	Elemento *txtNivel, *txtFase;
	Elemento *presentacionFase; // tiene la imagen de la presentacion de la fase
	Intercom *intercom;
	Uint32 velocidadJuego;
	Uint32 next_time;
	bool crearFiestaFinal3;
	
	bool EnPoderCadista;

	Elemento* cartelComoJugar, *flechasComoJugar, *pulsaComoJugar;
	int frameCartelMostrar; // -1 no muestra cartel

	// textos
	Elemento *txtSalir, *txtSi, *txtNo, *txtContinuar, *txtMensajeFinal;
	Elemento *txtFracasada, *txtPausa;
	
	Elemento *portada;
	
	SDL_Animation *introPortada;
	
public:
	int pulsadoSelPoder; // servirá para que sólo se dispare una bala por cada vez que se pulse disparo
	Elemento *caja;
	void ejecutar();
	int auxEstadoSalirPartida;
	Fuente *fuente;
	Audio *sonido;
	Joystick *joystick;
	SDL_Surface *screen;
	int salir;
	// tamaños de la pantalla
	int screen_w;
	int screen_h;
	int pantalla_w;
	int pantalla_h;
	Pantalla();
	void dibujarBarra() { barra->dibujarBarra(screen, juego, intercom); }
	// funciones de control de velocidad del juego
	Uint32 timeLeft(void);
	void nextTime();
	void setVelocidadJuego(Uint32 v) { velocidadJuego = v; }
	void guardarImg ();
	void dibujarImg ();
	void guardarImgTemblor ();
	// funciones de conversión de posiciones en pantalla según tamaño de screen
	int xEnPantalla (int x);
	int yEnPantalla (int y);
	int xEnPantalla(int div, int mul);
	int yEnPantalla(int div, int mul);
	void cargarConfiguracion ();
	Configuracion* getConfiguracion() { return config; }
	Intercom* getIntercom() { return intercom; }
	Juego* getJuego() { return juego; }
	Mapa* getMapa() { return mapa; }
	void modoScreen();
	void entradaJugador ();
	void morirJugador ();
	void dibujarJugador ();
	Jugador* getJugador () { return jugador; }
	void usarPoder ();
	void comprobarEstelaBomba();
	void comprobarBalones();
	void comprobarConversacionAleatoria();
	void initElementosComunes ();
	void initAutomoviles ();
	void initMarinos ();
	void initNivelComoJugar();
	void initNivel1();
	void initFinalNivel1 ();
	void initNivel2();
	void initFinalNivel2 ();
	void initNivel3();
	void initFinalNivel3 ();
	void initSpriteNivel (int l);
	void unLoadSpriteNivel (int l);
	void cargarSiguienteFase();
	void presentacion ();
	char* BufferFromRar(char *fileRar, char *file);
	void cargarIntro();
	void cargarVS();
	void cargarDiario();
	void setVolverAOpciones(bool b) { volverAOpciones = b; }
	int getVolverAOpciones() { return volverAOpciones; }
	void setHacerClip(int hc) { juego->setHacerClip(hc); }
	int getCiclos() { return juego->getCiclos(); }
	void setCiclos(int c) { juego->setCiclos(c); }
	int getVidas() { return juego->getVidas(); }
	void setGameOver (int go) { juego->setGameOver(go); }
	int getGameOver () { return juego->getGameOver(); }
	void setFinal(int f) { juego->setEnFinal(true); final = f; }
	int getFinal() { return final; }
	void setSalirFase(int f) { salirFase = f; jugador->setFantasma(1); }
	int getSalirFase() { return salirFase; }
	void Escena ();
	void EscenaFinal ();
	void dibujarFinal ();
	void dibujarFinal1 ();
	void dibujarFinal2 ();
	void dibujarFinal3 ();
	void EscenaEnComoJugar ();
	void dibujarCartelComoJugar(int framecartel);
	void EscenaEnPausa ();
	void EscenaEnGameOver (int est);
	void EscenaEnRecord (char tmpnom[50] );
	void EscenaEnSalirPartida (int est );
	void EscenaEnMensaje ();
	bool EscenaEnIntercom ();
	void EscenaEnSel_Poder ();
	void dibujarNubes ();
	void dibujarElTiempo ();
	void crearDisparoEnemigo ();
	void crearElemento ();
	void crearElementoComoJugar ();
	void crearElementoNivel1 ();
	void crearElementoNivel2 ();
	void crearElementoNivel3 ();
	void moverEnemigoTierra ();
	void moverEnemigoAire ();
	void comprobarScreenShot();
	void dibujarAgregadores();
	void crearChispa(float x, float y);
	void dibujarChispas();
	void crearAgregador(int ta, int x, int y);
	void crearAgregador(int ta, int x, int y, int dx, int dy);
	void comprobarColisiones();
	void eliminarEnemigosPantalla();
	void unLoad();
	void iniciarPantalla();
	void iniciarJuego();
	void empezarMusica(int l);
	void empezarMusicaFase();
	void empezarMusicaFinal();
	void empezarFaseEnTrozo(int trozo); // la pantalla la dividimos en trozo de altos de pantalla
										// empezamos la fase en un trozo concreto
	void cargarMitadVersus();
};

#endif /* PANTALLA_H_ */
